# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'FunctionJavaScriptUDFInput',
    'FunctionJavaScriptUDFOutput',
    'FunctionJavascriptUdaInput',
    'FunctionJavascriptUdaOutput',
    'JobIdentity',
    'JobJobStorageAccount',
    'OutputBlobSerialization',
    'OutputEventHubSerialization',
    'OutputServiceBusQueueSerialization',
    'OutputServicebusTopicSerialization',
    'ReferenceInputBlobSerialization',
    'StreamInputBlobSerialization',
    'StreamInputEventHubSerialization',
    'StreamInputEventHubV2Serialization',
    'StreamInputIotHubSerialization',
    'GetJobIdentityResult',
]

@pulumi.output_type
class FunctionJavaScriptUDFInput(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "configurationParameter":
            suggest = "configuration_parameter"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FunctionJavaScriptUDFInput. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FunctionJavaScriptUDFInput.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FunctionJavaScriptUDFInput.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: str,
                 configuration_parameter: Optional[bool] = None):
        """
        :param str type: The Data Type for the Input Argument of this JavaScript Function. Possible values include `array`, `any`, `bigint`, `datetime`, `float`, `nvarchar(max)` and `record`.
        :param bool configuration_parameter: Is this input parameter a configuration parameter? Defaults to `false`.
        """
        pulumi.set(__self__, "type", type)
        if configuration_parameter is not None:
            pulumi.set(__self__, "configuration_parameter", configuration_parameter)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The Data Type for the Input Argument of this JavaScript Function. Possible values include `array`, `any`, `bigint`, `datetime`, `float`, `nvarchar(max)` and `record`.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="configurationParameter")
    def configuration_parameter(self) -> Optional[bool]:
        """
        Is this input parameter a configuration parameter? Defaults to `false`.
        """
        return pulumi.get(self, "configuration_parameter")


@pulumi.output_type
class FunctionJavaScriptUDFOutput(dict):
    def __init__(__self__, *,
                 type: str):
        """
        :param str type: The Data Type output from this JavaScript Function. Possible values include `array`, `any`, `bigint`, `datetime`, `float`, `nvarchar(max)` and `record`.
        """
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The Data Type output from this JavaScript Function. Possible values include `array`, `any`, `bigint`, `datetime`, `float`, `nvarchar(max)` and `record`.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class FunctionJavascriptUdaInput(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "configurationParameter":
            suggest = "configuration_parameter"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FunctionJavascriptUdaInput. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FunctionJavascriptUdaInput.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FunctionJavascriptUdaInput.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: str,
                 configuration_parameter: Optional[bool] = None):
        """
        :param str type: The input data type of this JavaScript Function. Possible values include `any`, `array`, `bigint`, `datetime`, `float`, `nvarchar(max)` and `record`.
        :param bool configuration_parameter: Is this input parameter a configuration parameter? Defaults to `false`.
        """
        pulumi.set(__self__, "type", type)
        if configuration_parameter is not None:
            pulumi.set(__self__, "configuration_parameter", configuration_parameter)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The input data type of this JavaScript Function. Possible values include `any`, `array`, `bigint`, `datetime`, `float`, `nvarchar(max)` and `record`.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="configurationParameter")
    def configuration_parameter(self) -> Optional[bool]:
        """
        Is this input parameter a configuration parameter? Defaults to `false`.
        """
        return pulumi.get(self, "configuration_parameter")


@pulumi.output_type
class FunctionJavascriptUdaOutput(dict):
    def __init__(__self__, *,
                 type: str):
        """
        :param str type: The output data type from this JavaScript Function. Possible values include `any`, `array`, `bigint`, `datetime`, `float`, `nvarchar(max)` and `record`.
        """
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The output data type from this JavaScript Function. Possible values include `any`, `array`, `bigint`, `datetime`, `float`, `nvarchar(max)` and `record`.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class JobIdentity(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "identityIds":
            suggest = "identity_ids"
        elif key == "principalId":
            suggest = "principal_id"
        elif key == "tenantId":
            suggest = "tenant_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in JobIdentity. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        JobIdentity.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        JobIdentity.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: str,
                 identity_ids: Optional[Sequence[str]] = None,
                 principal_id: Optional[str] = None,
                 tenant_id: Optional[str] = None):
        """
        :param str type: Specifies the type of Managed Service Identity that should be configured on this Stream Analytics Job. Possible values are `SystemAssigned` and `UserAssigned`.
        :param Sequence[str] identity_ids: The identity id of the user assigned identity to use when type is `UserAssigned`
        :param str principal_id: The Principal ID associated with this Managed Service Identity.
        :param str tenant_id: The Tenant ID associated with this Managed Service Identity.
        """
        pulumi.set(__self__, "type", type)
        if identity_ids is not None:
            pulumi.set(__self__, "identity_ids", identity_ids)
        if principal_id is not None:
            pulumi.set(__self__, "principal_id", principal_id)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Specifies the type of Managed Service Identity that should be configured on this Stream Analytics Job. Possible values are `SystemAssigned` and `UserAssigned`.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Optional[Sequence[str]]:
        """
        The identity id of the user assigned identity to use when type is `UserAssigned`
        """
        return pulumi.get(self, "identity_ids")

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> Optional[str]:
        """
        The Principal ID associated with this Managed Service Identity.
        """
        return pulumi.get(self, "principal_id")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[str]:
        """
        The Tenant ID associated with this Managed Service Identity.
        """
        return pulumi.get(self, "tenant_id")


@pulumi.output_type
class JobJobStorageAccount(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "accountKey":
            suggest = "account_key"
        elif key == "accountName":
            suggest = "account_name"
        elif key == "authenticationMode":
            suggest = "authentication_mode"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in JobJobStorageAccount. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        JobJobStorageAccount.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        JobJobStorageAccount.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 account_key: str,
                 account_name: str,
                 authentication_mode: Optional[str] = None):
        """
        :param str account_key: The account key for the Azure storage account.
        :param str account_name: The name of the Azure storage account.
        :param str authentication_mode: The authentication mode of the storage account. The only supported value is `ConnectionString`. Defaults to `ConnectionString`.
        """
        pulumi.set(__self__, "account_key", account_key)
        pulumi.set(__self__, "account_name", account_name)
        if authentication_mode is not None:
            pulumi.set(__self__, "authentication_mode", authentication_mode)

    @property
    @pulumi.getter(name="accountKey")
    def account_key(self) -> str:
        """
        The account key for the Azure storage account.
        """
        return pulumi.get(self, "account_key")

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> str:
        """
        The name of the Azure storage account.
        """
        return pulumi.get(self, "account_name")

    @property
    @pulumi.getter(name="authenticationMode")
    def authentication_mode(self) -> Optional[str]:
        """
        The authentication mode of the storage account. The only supported value is `ConnectionString`. Defaults to `ConnectionString`.
        """
        return pulumi.get(self, "authentication_mode")


@pulumi.output_type
class OutputBlobSerialization(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "fieldDelimiter":
            suggest = "field_delimiter"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in OutputBlobSerialization. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        OutputBlobSerialization.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        OutputBlobSerialization.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: str,
                 encoding: Optional[str] = None,
                 field_delimiter: Optional[str] = None,
                 format: Optional[str] = None):
        """
        :param str type: The serialization format used for outgoing data streams. Possible values are `Avro`, `Csv`, `Json` and `Parquet`.
               
               > **NOTE:** `batch_max_wait_time` and `batch_min_rows` are required when `type` is set to `Parquet`
        :param str encoding: The encoding of the incoming data in the case of input and the encoding of outgoing data in the case of output. It currently can only be set to `UTF8`.
               
               > **NOTE:** This is required when `type` is set to `Csv` or `Json`.
        :param str field_delimiter: The delimiter that will be used to separate comma-separated value (CSV) records. Possible values are ` ` (space), `,` (comma), `	` (tab), `|` (pipe) and `;`.
               
               > **NOTE:** This is required when `type` is set to `Csv`.
        :param str format: Specifies the format of the JSON the output will be written in. Possible values are `Array` and `LineSeparated`.
               
               > **NOTE:** This is Required and can only be specified when `type` is set to `Json`.
        """
        pulumi.set(__self__, "type", type)
        if encoding is not None:
            pulumi.set(__self__, "encoding", encoding)
        if field_delimiter is not None:
            pulumi.set(__self__, "field_delimiter", field_delimiter)
        if format is not None:
            pulumi.set(__self__, "format", format)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The serialization format used for outgoing data streams. Possible values are `Avro`, `Csv`, `Json` and `Parquet`.

        > **NOTE:** `batch_max_wait_time` and `batch_min_rows` are required when `type` is set to `Parquet`
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def encoding(self) -> Optional[str]:
        """
        The encoding of the incoming data in the case of input and the encoding of outgoing data in the case of output. It currently can only be set to `UTF8`.

        > **NOTE:** This is required when `type` is set to `Csv` or `Json`.
        """
        return pulumi.get(self, "encoding")

    @property
    @pulumi.getter(name="fieldDelimiter")
    def field_delimiter(self) -> Optional[str]:
        """
        The delimiter that will be used to separate comma-separated value (CSV) records. Possible values are ` ` (space), `,` (comma), `	` (tab), `|` (pipe) and `;`.

        > **NOTE:** This is required when `type` is set to `Csv`.
        """
        return pulumi.get(self, "field_delimiter")

    @property
    @pulumi.getter
    def format(self) -> Optional[str]:
        """
        Specifies the format of the JSON the output will be written in. Possible values are `Array` and `LineSeparated`.

        > **NOTE:** This is Required and can only be specified when `type` is set to `Json`.
        """
        return pulumi.get(self, "format")


@pulumi.output_type
class OutputEventHubSerialization(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "fieldDelimiter":
            suggest = "field_delimiter"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in OutputEventHubSerialization. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        OutputEventHubSerialization.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        OutputEventHubSerialization.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: str,
                 encoding: Optional[str] = None,
                 field_delimiter: Optional[str] = None,
                 format: Optional[str] = None):
        """
        :param str type: The serialization format used for outgoing data streams. Possible values are `Avro`, `Csv`, `Json` and `Parquet`.
        :param str encoding: The encoding of the incoming data in the case of input and the encoding of outgoing data in the case of output. It currently can only be set to `UTF8`.
               
               > **NOTE:** This is required when `type` is set to `Csv` or `Json`.
        :param str field_delimiter: The delimiter that will be used to separate comma-separated value (CSV) records. Possible values are ` ` (space), `,` (comma), `	` (tab), `|` (pipe) and `;`.
               
               > **NOTE:** This is required when `type` is set to `Csv`.
        :param str format: Specifies the format of the JSON the output will be written in. Possible values are `Array` and `LineSeparated`.
               
               > **NOTE:** This is Required and can only be specified when `type` is set to `Json`.
        """
        pulumi.set(__self__, "type", type)
        if encoding is not None:
            pulumi.set(__self__, "encoding", encoding)
        if field_delimiter is not None:
            pulumi.set(__self__, "field_delimiter", field_delimiter)
        if format is not None:
            pulumi.set(__self__, "format", format)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The serialization format used for outgoing data streams. Possible values are `Avro`, `Csv`, `Json` and `Parquet`.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def encoding(self) -> Optional[str]:
        """
        The encoding of the incoming data in the case of input and the encoding of outgoing data in the case of output. It currently can only be set to `UTF8`.

        > **NOTE:** This is required when `type` is set to `Csv` or `Json`.
        """
        return pulumi.get(self, "encoding")

    @property
    @pulumi.getter(name="fieldDelimiter")
    def field_delimiter(self) -> Optional[str]:
        """
        The delimiter that will be used to separate comma-separated value (CSV) records. Possible values are ` ` (space), `,` (comma), `	` (tab), `|` (pipe) and `;`.

        > **NOTE:** This is required when `type` is set to `Csv`.
        """
        return pulumi.get(self, "field_delimiter")

    @property
    @pulumi.getter
    def format(self) -> Optional[str]:
        """
        Specifies the format of the JSON the output will be written in. Possible values are `Array` and `LineSeparated`.

        > **NOTE:** This is Required and can only be specified when `type` is set to `Json`.
        """
        return pulumi.get(self, "format")


@pulumi.output_type
class OutputServiceBusQueueSerialization(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "fieldDelimiter":
            suggest = "field_delimiter"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in OutputServiceBusQueueSerialization. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        OutputServiceBusQueueSerialization.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        OutputServiceBusQueueSerialization.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: str,
                 encoding: Optional[str] = None,
                 field_delimiter: Optional[str] = None,
                 format: Optional[str] = None):
        """
        :param str type: The serialization format used for outgoing data streams. Possible values are `Avro`, `Csv`, `Json` and `Parquet`.
        :param str encoding: The encoding of the incoming data in the case of input and the encoding of outgoing data in the case of output. It currently can only be set to `UTF8`.
               
               > **NOTE:** This is required when `type` is set to `Csv` or `Json`.
        :param str field_delimiter: The delimiter that will be used to separate comma-separated value (CSV) records. Possible values are ` ` (space), `,` (comma), `	` (tab), `|` (pipe) and `;`.
               
               > **NOTE:** This is required when `type` is set to `Csv`.
        :param str format: Specifies the format of the JSON the output will be written in. Possible values are `Array` and `LineSeparated`.
               
               > **NOTE:** This is Required and can only be specified when `type` is set to `Json`.
        """
        pulumi.set(__self__, "type", type)
        if encoding is not None:
            pulumi.set(__self__, "encoding", encoding)
        if field_delimiter is not None:
            pulumi.set(__self__, "field_delimiter", field_delimiter)
        if format is not None:
            pulumi.set(__self__, "format", format)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The serialization format used for outgoing data streams. Possible values are `Avro`, `Csv`, `Json` and `Parquet`.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def encoding(self) -> Optional[str]:
        """
        The encoding of the incoming data in the case of input and the encoding of outgoing data in the case of output. It currently can only be set to `UTF8`.

        > **NOTE:** This is required when `type` is set to `Csv` or `Json`.
        """
        return pulumi.get(self, "encoding")

    @property
    @pulumi.getter(name="fieldDelimiter")
    def field_delimiter(self) -> Optional[str]:
        """
        The delimiter that will be used to separate comma-separated value (CSV) records. Possible values are ` ` (space), `,` (comma), `	` (tab), `|` (pipe) and `;`.

        > **NOTE:** This is required when `type` is set to `Csv`.
        """
        return pulumi.get(self, "field_delimiter")

    @property
    @pulumi.getter
    def format(self) -> Optional[str]:
        """
        Specifies the format of the JSON the output will be written in. Possible values are `Array` and `LineSeparated`.

        > **NOTE:** This is Required and can only be specified when `type` is set to `Json`.
        """
        return pulumi.get(self, "format")


@pulumi.output_type
class OutputServicebusTopicSerialization(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "fieldDelimiter":
            suggest = "field_delimiter"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in OutputServicebusTopicSerialization. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        OutputServicebusTopicSerialization.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        OutputServicebusTopicSerialization.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: str,
                 encoding: Optional[str] = None,
                 field_delimiter: Optional[str] = None,
                 format: Optional[str] = None):
        """
        :param str type: The serialization format used for outgoing data streams. Possible values are `Avro`, `Csv`, `Json` and `Parquet`.
        :param str encoding: The encoding of the incoming data in the case of input and the encoding of outgoing data in the case of output. It currently can only be set to `UTF8`.
               
               > **NOTE:** This is required when `type` is set to `Csv` or `Json`.
        :param str field_delimiter: The delimiter that will be used to separate comma-separated value (CSV) records. Possible values are ` ` (space), `,` (comma), `	` (tab), `|` (pipe) and `;`.
               
               > **NOTE:** This is required when `type` is set to `Csv`.
        :param str format: Specifies the format of the JSON the output will be written in. Possible values are `Array` and `LineSeparated`.
               
               > **NOTE:** This is Required and can only be specified when `type` is set to `Json`.
        """
        pulumi.set(__self__, "type", type)
        if encoding is not None:
            pulumi.set(__self__, "encoding", encoding)
        if field_delimiter is not None:
            pulumi.set(__self__, "field_delimiter", field_delimiter)
        if format is not None:
            pulumi.set(__self__, "format", format)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The serialization format used for outgoing data streams. Possible values are `Avro`, `Csv`, `Json` and `Parquet`.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def encoding(self) -> Optional[str]:
        """
        The encoding of the incoming data in the case of input and the encoding of outgoing data in the case of output. It currently can only be set to `UTF8`.

        > **NOTE:** This is required when `type` is set to `Csv` or `Json`.
        """
        return pulumi.get(self, "encoding")

    @property
    @pulumi.getter(name="fieldDelimiter")
    def field_delimiter(self) -> Optional[str]:
        """
        The delimiter that will be used to separate comma-separated value (CSV) records. Possible values are ` ` (space), `,` (comma), `	` (tab), `|` (pipe) and `;`.

        > **NOTE:** This is required when `type` is set to `Csv`.
        """
        return pulumi.get(self, "field_delimiter")

    @property
    @pulumi.getter
    def format(self) -> Optional[str]:
        """
        Specifies the format of the JSON the output will be written in. Possible values are `Array` and `LineSeparated`.

        > **NOTE:** This is Required and can only be specified when `type` is set to `Json`.
        """
        return pulumi.get(self, "format")


@pulumi.output_type
class ReferenceInputBlobSerialization(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "fieldDelimiter":
            suggest = "field_delimiter"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ReferenceInputBlobSerialization. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ReferenceInputBlobSerialization.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ReferenceInputBlobSerialization.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: str,
                 encoding: Optional[str] = None,
                 field_delimiter: Optional[str] = None):
        """
        :param str type: The serialization format used for the reference data. Possible values are `Avro`, `Csv` and `Json`.
        :param str encoding: The encoding of the incoming data in the case of input and the encoding of outgoing data in the case of output. It currently can only be set to `UTF8`.
               
               > **NOTE:** This is required when `type` is set to `Csv` or `Json`.
        :param str field_delimiter: The delimiter that will be used to separate comma-separated value (CSV) records. Possible values are ` ` (space), `,` (comma), `	` (tab), `|` (pipe) and `;`.
               
               > **NOTE:** This is required when `type` is set to `Csv`.
        """
        pulumi.set(__self__, "type", type)
        if encoding is not None:
            pulumi.set(__self__, "encoding", encoding)
        if field_delimiter is not None:
            pulumi.set(__self__, "field_delimiter", field_delimiter)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The serialization format used for the reference data. Possible values are `Avro`, `Csv` and `Json`.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def encoding(self) -> Optional[str]:
        """
        The encoding of the incoming data in the case of input and the encoding of outgoing data in the case of output. It currently can only be set to `UTF8`.

        > **NOTE:** This is required when `type` is set to `Csv` or `Json`.
        """
        return pulumi.get(self, "encoding")

    @property
    @pulumi.getter(name="fieldDelimiter")
    def field_delimiter(self) -> Optional[str]:
        """
        The delimiter that will be used to separate comma-separated value (CSV) records. Possible values are ` ` (space), `,` (comma), `	` (tab), `|` (pipe) and `;`.

        > **NOTE:** This is required when `type` is set to `Csv`.
        """
        return pulumi.get(self, "field_delimiter")


@pulumi.output_type
class StreamInputBlobSerialization(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "fieldDelimiter":
            suggest = "field_delimiter"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in StreamInputBlobSerialization. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        StreamInputBlobSerialization.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        StreamInputBlobSerialization.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: str,
                 encoding: Optional[str] = None,
                 field_delimiter: Optional[str] = None):
        """
        :param str type: The serialization format used for incoming data streams. Possible values are `Avro`, `Csv` and `Json`.
        :param str encoding: The encoding of the incoming data in the case of input and the encoding of outgoing data in the case of output. It currently can only be set to `UTF8`.
               
               > **NOTE:** This is required when `type` is set to `Csv` or `Json`.
        :param str field_delimiter: The delimiter that will be used to separate comma-separated value (CSV) records. Possible values are ` ` (space), `,` (comma), `	` (tab), `|` (pipe) and `;`.
               
               > **NOTE:** This is required when `type` is set to `Csv`.
        """
        pulumi.set(__self__, "type", type)
        if encoding is not None:
            pulumi.set(__self__, "encoding", encoding)
        if field_delimiter is not None:
            pulumi.set(__self__, "field_delimiter", field_delimiter)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The serialization format used for incoming data streams. Possible values are `Avro`, `Csv` and `Json`.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def encoding(self) -> Optional[str]:
        """
        The encoding of the incoming data in the case of input and the encoding of outgoing data in the case of output. It currently can only be set to `UTF8`.

        > **NOTE:** This is required when `type` is set to `Csv` or `Json`.
        """
        return pulumi.get(self, "encoding")

    @property
    @pulumi.getter(name="fieldDelimiter")
    def field_delimiter(self) -> Optional[str]:
        """
        The delimiter that will be used to separate comma-separated value (CSV) records. Possible values are ` ` (space), `,` (comma), `	` (tab), `|` (pipe) and `;`.

        > **NOTE:** This is required when `type` is set to `Csv`.
        """
        return pulumi.get(self, "field_delimiter")


@pulumi.output_type
class StreamInputEventHubSerialization(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "fieldDelimiter":
            suggest = "field_delimiter"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in StreamInputEventHubSerialization. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        StreamInputEventHubSerialization.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        StreamInputEventHubSerialization.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: str,
                 encoding: Optional[str] = None,
                 field_delimiter: Optional[str] = None):
        """
        :param str type: The serialization format used for incoming data streams. Possible values are `Avro`, `Csv` and `Json`.
        :param str encoding: The encoding of the incoming data in the case of input and the encoding of outgoing data in the case of output. It currently can only be set to `UTF8`.
               
               > **NOTE:** This is required when `type` is set to `Csv` or `Json`.
        :param str field_delimiter: The delimiter that will be used to separate comma-separated value (CSV) records. Possible values are ` ` (space), `,` (comma), `	` (tab), `|` (pipe) and `;`.
               
               > **NOTE:** This is required when `type` is set to `Csv`.
        """
        pulumi.set(__self__, "type", type)
        if encoding is not None:
            pulumi.set(__self__, "encoding", encoding)
        if field_delimiter is not None:
            pulumi.set(__self__, "field_delimiter", field_delimiter)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The serialization format used for incoming data streams. Possible values are `Avro`, `Csv` and `Json`.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def encoding(self) -> Optional[str]:
        """
        The encoding of the incoming data in the case of input and the encoding of outgoing data in the case of output. It currently can only be set to `UTF8`.

        > **NOTE:** This is required when `type` is set to `Csv` or `Json`.
        """
        return pulumi.get(self, "encoding")

    @property
    @pulumi.getter(name="fieldDelimiter")
    def field_delimiter(self) -> Optional[str]:
        """
        The delimiter that will be used to separate comma-separated value (CSV) records. Possible values are ` ` (space), `,` (comma), `	` (tab), `|` (pipe) and `;`.

        > **NOTE:** This is required when `type` is set to `Csv`.
        """
        return pulumi.get(self, "field_delimiter")


@pulumi.output_type
class StreamInputEventHubV2Serialization(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "fieldDelimiter":
            suggest = "field_delimiter"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in StreamInputEventHubV2Serialization. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        StreamInputEventHubV2Serialization.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        StreamInputEventHubV2Serialization.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: str,
                 encoding: Optional[str] = None,
                 field_delimiter: Optional[str] = None):
        """
        :param str type: The serialization format used for incoming data streams. Possible values are `Avro`, `Csv` and `Json`.
        :param str encoding: The encoding of the incoming data in the case of input and the encoding of outgoing data in the case of output. It currently can only be set to `UTF8`.
               
               > **NOTE:** This is required when `type` is set to `Csv` or `Json`.
        :param str field_delimiter: The delimiter that will be used to separate comma-separated value (CSV) records. Possible values are ` ` (space), `,` (comma), `	` (tab), `|` (pipe) and `;`.
               
               > **NOTE:** This is required when `type` is set to `Csv`.
        """
        pulumi.set(__self__, "type", type)
        if encoding is not None:
            pulumi.set(__self__, "encoding", encoding)
        if field_delimiter is not None:
            pulumi.set(__self__, "field_delimiter", field_delimiter)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The serialization format used for incoming data streams. Possible values are `Avro`, `Csv` and `Json`.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def encoding(self) -> Optional[str]:
        """
        The encoding of the incoming data in the case of input and the encoding of outgoing data in the case of output. It currently can only be set to `UTF8`.

        > **NOTE:** This is required when `type` is set to `Csv` or `Json`.
        """
        return pulumi.get(self, "encoding")

    @property
    @pulumi.getter(name="fieldDelimiter")
    def field_delimiter(self) -> Optional[str]:
        """
        The delimiter that will be used to separate comma-separated value (CSV) records. Possible values are ` ` (space), `,` (comma), `	` (tab), `|` (pipe) and `;`.

        > **NOTE:** This is required when `type` is set to `Csv`.
        """
        return pulumi.get(self, "field_delimiter")


@pulumi.output_type
class StreamInputIotHubSerialization(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "fieldDelimiter":
            suggest = "field_delimiter"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in StreamInputIotHubSerialization. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        StreamInputIotHubSerialization.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        StreamInputIotHubSerialization.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: str,
                 encoding: Optional[str] = None,
                 field_delimiter: Optional[str] = None):
        """
        :param str type: The serialization format used for incoming data streams. Possible values are `Avro`, `Csv` and `Json`.
        :param str encoding: The encoding of the incoming data in the case of input and the encoding of outgoing data in the case of output. It currently can only be set to `UTF8`.
               
               > **NOTE:** This is required when `type` is set to `Csv` or `Json`.
        :param str field_delimiter: The delimiter that will be used to separate comma-separated value (CSV) records. Possible values are ` ` (space), `,` (comma), `	` (tab), `|` (pipe) and `;`.
               
               > **NOTE:** This is required when `type` is set to `Csv`.
        """
        pulumi.set(__self__, "type", type)
        if encoding is not None:
            pulumi.set(__self__, "encoding", encoding)
        if field_delimiter is not None:
            pulumi.set(__self__, "field_delimiter", field_delimiter)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The serialization format used for incoming data streams. Possible values are `Avro`, `Csv` and `Json`.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def encoding(self) -> Optional[str]:
        """
        The encoding of the incoming data in the case of input and the encoding of outgoing data in the case of output. It currently can only be set to `UTF8`.

        > **NOTE:** This is required when `type` is set to `Csv` or `Json`.
        """
        return pulumi.get(self, "encoding")

    @property
    @pulumi.getter(name="fieldDelimiter")
    def field_delimiter(self) -> Optional[str]:
        """
        The delimiter that will be used to separate comma-separated value (CSV) records. Possible values are ` ` (space), `,` (comma), `	` (tab), `|` (pipe) and `;`.

        > **NOTE:** This is required when `type` is set to `Csv`.
        """
        return pulumi.get(self, "field_delimiter")


@pulumi.output_type
class GetJobIdentityResult(dict):
    def __init__(__self__, *,
                 identity_ids: Sequence[str],
                 principal_id: str,
                 tenant_id: str,
                 type: str):
        """
        :param Sequence[str] identity_ids: A list of User Assigned Managed Identity IDs assigned to this resource.
        :param str principal_id: The Principal ID associated with this Managed Service Identity.
        :param str tenant_id: The Tenant ID associated with this Managed Service Identity.
        :param str type: The identity type of this Managed Service Identity.
        """
        pulumi.set(__self__, "identity_ids", identity_ids)
        pulumi.set(__self__, "principal_id", principal_id)
        pulumi.set(__self__, "tenant_id", tenant_id)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Sequence[str]:
        """
        A list of User Assigned Managed Identity IDs assigned to this resource.
        """
        return pulumi.get(self, "identity_ids")

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> str:
        """
        The Principal ID associated with this Managed Service Identity.
        """
        return pulumi.get(self, "principal_id")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> str:
        """
        The Tenant ID associated with this Managed Service Identity.
        """
        return pulumi.get(self, "tenant_id")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The identity type of this Managed Service Identity.
        """
        return pulumi.get(self, "type")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['SlotVirtualNetworkSwiftConnectionArgs', 'SlotVirtualNetworkSwiftConnection']

@pulumi.input_type
class SlotVirtualNetworkSwiftConnectionArgs:
    def __init__(__self__, *,
                 app_service_id: pulumi.Input[str],
                 slot_name: pulumi.Input[str],
                 subnet_id: pulumi.Input[str]):
        """
        The set of arguments for constructing a SlotVirtualNetworkSwiftConnection resource.
        :param pulumi.Input[str] app_service_id: The ID of the App Service or Function App to associate to the VNet. Changing this forces a new resource to be created.
        :param pulumi.Input[str] slot_name: The name of the App Service Slot or Function App Slot. Changing this forces a new resource to be created.
        :param pulumi.Input[str] subnet_id: The ID of the subnet the app service will be associated to (the subnet must have a `service_delegation` configured for `Microsoft.Web/serverFarms`).
        """
        pulumi.set(__self__, "app_service_id", app_service_id)
        pulumi.set(__self__, "slot_name", slot_name)
        pulumi.set(__self__, "subnet_id", subnet_id)

    @property
    @pulumi.getter(name="appServiceId")
    def app_service_id(self) -> pulumi.Input[str]:
        """
        The ID of the App Service or Function App to associate to the VNet. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "app_service_id")

    @app_service_id.setter
    def app_service_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "app_service_id", value)

    @property
    @pulumi.getter(name="slotName")
    def slot_name(self) -> pulumi.Input[str]:
        """
        The name of the App Service Slot or Function App Slot. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "slot_name")

    @slot_name.setter
    def slot_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "slot_name", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Input[str]:
        """
        The ID of the subnet the app service will be associated to (the subnet must have a `service_delegation` configured for `Microsoft.Web/serverFarms`).
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "subnet_id", value)


@pulumi.input_type
class _SlotVirtualNetworkSwiftConnectionState:
    def __init__(__self__, *,
                 app_service_id: Optional[pulumi.Input[str]] = None,
                 slot_name: Optional[pulumi.Input[str]] = None,
                 subnet_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering SlotVirtualNetworkSwiftConnection resources.
        :param pulumi.Input[str] app_service_id: The ID of the App Service or Function App to associate to the VNet. Changing this forces a new resource to be created.
        :param pulumi.Input[str] slot_name: The name of the App Service Slot or Function App Slot. Changing this forces a new resource to be created.
        :param pulumi.Input[str] subnet_id: The ID of the subnet the app service will be associated to (the subnet must have a `service_delegation` configured for `Microsoft.Web/serverFarms`).
        """
        if app_service_id is not None:
            pulumi.set(__self__, "app_service_id", app_service_id)
        if slot_name is not None:
            pulumi.set(__self__, "slot_name", slot_name)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)

    @property
    @pulumi.getter(name="appServiceId")
    def app_service_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the App Service or Function App to associate to the VNet. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "app_service_id")

    @app_service_id.setter
    def app_service_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "app_service_id", value)

    @property
    @pulumi.getter(name="slotName")
    def slot_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the App Service Slot or Function App Slot. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "slot_name")

    @slot_name.setter
    def slot_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "slot_name", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the subnet the app service will be associated to (the subnet must have a `service_delegation` configured for `Microsoft.Web/serverFarms`).
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "subnet_id", value)


class SlotVirtualNetworkSwiftConnection(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_service_id: Optional[pulumi.Input[str]] = None,
                 slot_name: Optional[pulumi.Input[str]] = None,
                 subnet_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages an App Service Slot's Virtual Network Association (this is for the [Regional VNet Integration](https://docs.microsoft.com/azure/app-service/web-sites-integrate-with-vnet#regional-vnet-integration) which is still in preview).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_virtual_network = azure.network.VirtualNetwork("example",
            name="example-virtual-network",
            address_spaces=["10.0.0.0/16"],
            location=example.location,
            resource_group_name=example.name)
        example_subnet = azure.network.Subnet("example",
            name="example-subnet",
            resource_group_name=example.name,
            virtual_network_name=example_virtual_network.name,
            address_prefixes=["10.0.1.0/24"],
            delegations=[{
                "name": "example-delegation",
                "service_delegation": {
                    "name": "Microsoft.Web/serverFarms",
                    "actions": ["Microsoft.Network/virtualNetworks/subnets/action"],
                },
            }])
        example_plan = azure.appservice.Plan("example",
            name="example-service-plan",
            location=example.location,
            resource_group_name=example.name,
            sku={
                "tier": "Standard",
                "size": "S1",
            })
        example_app_service = azure.appservice.AppService("example",
            name="example-app-service",
            location=example.location,
            resource_group_name=example.name,
            app_service_plan_id=example_plan.id)
        example_staging = azure.appservice.Slot("example-staging",
            name="staging",
            app_service_name=example_app_service.name,
            location=example.location,
            resource_group_name=example.name,
            app_service_plan_id=example_plan.id)
        example_slot_virtual_network_swift_connection = azure.appservice.SlotVirtualNetworkSwiftConnection("example",
            slot_name=example_staging.name,
            app_service_id=example_app_service.id,
            subnet_id=example_subnet.id)
        ```

        ## Import

        App Service Slot Virtual Network Associations can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:appservice/slotVirtualNetworkSwiftConnection:SlotVirtualNetworkSwiftConnection myassociation /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/mygroup1/providers/Microsoft.Web/sites/instance1/slots/staging/config/virtualNetwork
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] app_service_id: The ID of the App Service or Function App to associate to the VNet. Changing this forces a new resource to be created.
        :param pulumi.Input[str] slot_name: The name of the App Service Slot or Function App Slot. Changing this forces a new resource to be created.
        :param pulumi.Input[str] subnet_id: The ID of the subnet the app service will be associated to (the subnet must have a `service_delegation` configured for `Microsoft.Web/serverFarms`).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SlotVirtualNetworkSwiftConnectionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages an App Service Slot's Virtual Network Association (this is for the [Regional VNet Integration](https://docs.microsoft.com/azure/app-service/web-sites-integrate-with-vnet#regional-vnet-integration) which is still in preview).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_virtual_network = azure.network.VirtualNetwork("example",
            name="example-virtual-network",
            address_spaces=["10.0.0.0/16"],
            location=example.location,
            resource_group_name=example.name)
        example_subnet = azure.network.Subnet("example",
            name="example-subnet",
            resource_group_name=example.name,
            virtual_network_name=example_virtual_network.name,
            address_prefixes=["10.0.1.0/24"],
            delegations=[{
                "name": "example-delegation",
                "service_delegation": {
                    "name": "Microsoft.Web/serverFarms",
                    "actions": ["Microsoft.Network/virtualNetworks/subnets/action"],
                },
            }])
        example_plan = azure.appservice.Plan("example",
            name="example-service-plan",
            location=example.location,
            resource_group_name=example.name,
            sku={
                "tier": "Standard",
                "size": "S1",
            })
        example_app_service = azure.appservice.AppService("example",
            name="example-app-service",
            location=example.location,
            resource_group_name=example.name,
            app_service_plan_id=example_plan.id)
        example_staging = azure.appservice.Slot("example-staging",
            name="staging",
            app_service_name=example_app_service.name,
            location=example.location,
            resource_group_name=example.name,
            app_service_plan_id=example_plan.id)
        example_slot_virtual_network_swift_connection = azure.appservice.SlotVirtualNetworkSwiftConnection("example",
            slot_name=example_staging.name,
            app_service_id=example_app_service.id,
            subnet_id=example_subnet.id)
        ```

        ## Import

        App Service Slot Virtual Network Associations can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:appservice/slotVirtualNetworkSwiftConnection:SlotVirtualNetworkSwiftConnection myassociation /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/mygroup1/providers/Microsoft.Web/sites/instance1/slots/staging/config/virtualNetwork
        ```

        :param str resource_name: The name of the resource.
        :param SlotVirtualNetworkSwiftConnectionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SlotVirtualNetworkSwiftConnectionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_service_id: Optional[pulumi.Input[str]] = None,
                 slot_name: Optional[pulumi.Input[str]] = None,
                 subnet_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SlotVirtualNetworkSwiftConnectionArgs.__new__(SlotVirtualNetworkSwiftConnectionArgs)

            if app_service_id is None and not opts.urn:
                raise TypeError("Missing required property 'app_service_id'")
            __props__.__dict__["app_service_id"] = app_service_id
            if slot_name is None and not opts.urn:
                raise TypeError("Missing required property 'slot_name'")
            __props__.__dict__["slot_name"] = slot_name
            if subnet_id is None and not opts.urn:
                raise TypeError("Missing required property 'subnet_id'")
            __props__.__dict__["subnet_id"] = subnet_id
        super(SlotVirtualNetworkSwiftConnection, __self__).__init__(
            'azure:appservice/slotVirtualNetworkSwiftConnection:SlotVirtualNetworkSwiftConnection',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_service_id: Optional[pulumi.Input[str]] = None,
            slot_name: Optional[pulumi.Input[str]] = None,
            subnet_id: Optional[pulumi.Input[str]] = None) -> 'SlotVirtualNetworkSwiftConnection':
        """
        Get an existing SlotVirtualNetworkSwiftConnection resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] app_service_id: The ID of the App Service or Function App to associate to the VNet. Changing this forces a new resource to be created.
        :param pulumi.Input[str] slot_name: The name of the App Service Slot or Function App Slot. Changing this forces a new resource to be created.
        :param pulumi.Input[str] subnet_id: The ID of the subnet the app service will be associated to (the subnet must have a `service_delegation` configured for `Microsoft.Web/serverFarms`).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SlotVirtualNetworkSwiftConnectionState.__new__(_SlotVirtualNetworkSwiftConnectionState)

        __props__.__dict__["app_service_id"] = app_service_id
        __props__.__dict__["slot_name"] = slot_name
        __props__.__dict__["subnet_id"] = subnet_id
        return SlotVirtualNetworkSwiftConnection(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="appServiceId")
    def app_service_id(self) -> pulumi.Output[str]:
        """
        The ID of the App Service or Function App to associate to the VNet. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "app_service_id")

    @property
    @pulumi.getter(name="slotName")
    def slot_name(self) -> pulumi.Output[str]:
        """
        The name of the App Service Slot or Function App Slot. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "slot_name")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Output[str]:
        """
        The ID of the subnet the app service will be associated to (the subnet must have a `service_delegation` configured for `Microsoft.Web/serverFarms`).
        """
        return pulumi.get(self, "subnet_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['JobScheduleArgs', 'JobSchedule']

@pulumi.input_type
class JobScheduleArgs:
    def __init__(__self__, *,
                 start_mode: pulumi.Input[str],
                 stream_analytics_job_id: pulumi.Input[str],
                 start_time: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a JobSchedule resource.
        :param pulumi.Input[str] start_mode: The starting mode of the Stream Analytics Job. Possible values are `JobStartTime`, `CustomTime` and `LastOutputEventTime`.
               
               > **Note:** Setting `start_mode` to `LastOutputEventTime` is only possible if the job had been previously started and produced output.
        :param pulumi.Input[str] stream_analytics_job_id: The ID of the Stream Analytics Job that should be scheduled or started. Changing this forces a new resource to be created.
        :param pulumi.Input[str] start_time: The time in ISO8601 format at which the Stream Analytics Job should be started e.g. `2022-04-01T00:00:00Z`. This property can only be specified if `start_mode` is set to `CustomTime`
        """
        pulumi.set(__self__, "start_mode", start_mode)
        pulumi.set(__self__, "stream_analytics_job_id", stream_analytics_job_id)
        if start_time is not None:
            pulumi.set(__self__, "start_time", start_time)

    @property
    @pulumi.getter(name="startMode")
    def start_mode(self) -> pulumi.Input[str]:
        """
        The starting mode of the Stream Analytics Job. Possible values are `JobStartTime`, `CustomTime` and `LastOutputEventTime`.

        > **Note:** Setting `start_mode` to `LastOutputEventTime` is only possible if the job had been previously started and produced output.
        """
        return pulumi.get(self, "start_mode")

    @start_mode.setter
    def start_mode(self, value: pulumi.Input[str]):
        pulumi.set(self, "start_mode", value)

    @property
    @pulumi.getter(name="streamAnalyticsJobId")
    def stream_analytics_job_id(self) -> pulumi.Input[str]:
        """
        The ID of the Stream Analytics Job that should be scheduled or started. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "stream_analytics_job_id")

    @stream_analytics_job_id.setter
    def stream_analytics_job_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "stream_analytics_job_id", value)

    @property
    @pulumi.getter(name="startTime")
    def start_time(self) -> Optional[pulumi.Input[str]]:
        """
        The time in ISO8601 format at which the Stream Analytics Job should be started e.g. `2022-04-01T00:00:00Z`. This property can only be specified if `start_mode` is set to `CustomTime`
        """
        return pulumi.get(self, "start_time")

    @start_time.setter
    def start_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "start_time", value)


@pulumi.input_type
class _JobScheduleState:
    def __init__(__self__, *,
                 last_output_time: Optional[pulumi.Input[str]] = None,
                 start_mode: Optional[pulumi.Input[str]] = None,
                 start_time: Optional[pulumi.Input[str]] = None,
                 stream_analytics_job_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering JobSchedule resources.
        :param pulumi.Input[str] last_output_time: The time at which the Stream Analytics job last produced an output.
        :param pulumi.Input[str] start_mode: The starting mode of the Stream Analytics Job. Possible values are `JobStartTime`, `CustomTime` and `LastOutputEventTime`.
               
               > **Note:** Setting `start_mode` to `LastOutputEventTime` is only possible if the job had been previously started and produced output.
        :param pulumi.Input[str] start_time: The time in ISO8601 format at which the Stream Analytics Job should be started e.g. `2022-04-01T00:00:00Z`. This property can only be specified if `start_mode` is set to `CustomTime`
        :param pulumi.Input[str] stream_analytics_job_id: The ID of the Stream Analytics Job that should be scheduled or started. Changing this forces a new resource to be created.
        """
        if last_output_time is not None:
            pulumi.set(__self__, "last_output_time", last_output_time)
        if start_mode is not None:
            pulumi.set(__self__, "start_mode", start_mode)
        if start_time is not None:
            pulumi.set(__self__, "start_time", start_time)
        if stream_analytics_job_id is not None:
            pulumi.set(__self__, "stream_analytics_job_id", stream_analytics_job_id)

    @property
    @pulumi.getter(name="lastOutputTime")
    def last_output_time(self) -> Optional[pulumi.Input[str]]:
        """
        The time at which the Stream Analytics job last produced an output.
        """
        return pulumi.get(self, "last_output_time")

    @last_output_time.setter
    def last_output_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_output_time", value)

    @property
    @pulumi.getter(name="startMode")
    def start_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The starting mode of the Stream Analytics Job. Possible values are `JobStartTime`, `CustomTime` and `LastOutputEventTime`.

        > **Note:** Setting `start_mode` to `LastOutputEventTime` is only possible if the job had been previously started and produced output.
        """
        return pulumi.get(self, "start_mode")

    @start_mode.setter
    def start_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "start_mode", value)

    @property
    @pulumi.getter(name="startTime")
    def start_time(self) -> Optional[pulumi.Input[str]]:
        """
        The time in ISO8601 format at which the Stream Analytics Job should be started e.g. `2022-04-01T00:00:00Z`. This property can only be specified if `start_mode` is set to `CustomTime`
        """
        return pulumi.get(self, "start_time")

    @start_time.setter
    def start_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "start_time", value)

    @property
    @pulumi.getter(name="streamAnalyticsJobId")
    def stream_analytics_job_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Stream Analytics Job that should be scheduled or started. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "stream_analytics_job_id")

    @stream_analytics_job_id.setter
    def stream_analytics_job_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "stream_analytics_job_id", value)


class JobSchedule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 start_mode: Optional[pulumi.Input[str]] = None,
                 start_time: Optional[pulumi.Input[str]] = None,
                 stream_analytics_job_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a Stream Analytics Job Schedule.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_account = azure.storage.Account("example",
            name="example",
            resource_group_name=example.name,
            location=example.location,
            account_tier="Standard",
            account_replication_type="LRS")
        example_container = azure.storage.Container("example",
            name="example",
            storage_account_name=example_account.name,
            container_access_type="private")
        example_blob = azure.storage.Blob("example",
            name="example",
            storage_account_name=example_account.name,
            storage_container_name=example_container.name,
            type="Block",
            source=pulumi.FileAsset("example.csv"))
        example_job = azure.streamanalytics.Job("example",
            name="example-job",
            resource_group_name=example.name,
            location=example.location,
            compatibility_level="1.2",
            data_locale="en-GB",
            events_late_arrival_max_delay_in_seconds=60,
            events_out_of_order_max_delay_in_seconds=50,
            events_out_of_order_policy="Adjust",
            output_error_policy="Drop",
            streaming_units=3,
            tags={
                "environment": "Example",
            },
            transformation_query=\"\"\"    SELECT *
            INTO [exampleoutput]
            FROM [exampleinput]
        \"\"\")
        example_stream_input_blob = azure.streamanalytics.StreamInputBlob("example",
            name="exampleinput",
            stream_analytics_job_name=example_job.name,
            resource_group_name=example_job.resource_group_name,
            storage_account_name=example_account.name,
            storage_account_key=example_account.primary_access_key,
            storage_container_name=example_container.name,
            path_pattern="",
            date_format="yyyy/MM/dd",
            time_format="HH",
            serialization={
                "type": "Csv",
                "encoding": "UTF8",
                "field_delimiter": ",",
            })
        example_output_blob = azure.streamanalytics.OutputBlob("example",
            name="exampleoutput",
            stream_analytics_job_name=example_job.name,
            resource_group_name=example_job.resource_group_name,
            storage_account_name=example_account.name,
            storage_account_key=example_account.primary_access_key,
            storage_container_name=example_container.name,
            path_pattern="example-{date}-{time}",
            date_format="yyyy-MM-dd",
            time_format="HH",
            serialization={
                "type": "Avro",
            })
        example_job_schedule = azure.streamanalytics.JobSchedule("example",
            stream_analytics_job_id=example_job.id,
            start_mode="CustomTime",
            start_time="2022-09-21T00:00:00Z",
            opts = pulumi.ResourceOptions(depends_on=[
                    example_job,
                    example_stream_input_blob,
                    example_output_blob,
                ]))
        ```

        ## Import

        Stream Analytics Job's can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:streamanalytics/jobSchedule:JobSchedule example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.StreamAnalytics/streamingJobs/job1/schedule/default
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] start_mode: The starting mode of the Stream Analytics Job. Possible values are `JobStartTime`, `CustomTime` and `LastOutputEventTime`.
               
               > **Note:** Setting `start_mode` to `LastOutputEventTime` is only possible if the job had been previously started and produced output.
        :param pulumi.Input[str] start_time: The time in ISO8601 format at which the Stream Analytics Job should be started e.g. `2022-04-01T00:00:00Z`. This property can only be specified if `start_mode` is set to `CustomTime`
        :param pulumi.Input[str] stream_analytics_job_id: The ID of the Stream Analytics Job that should be scheduled or started. Changing this forces a new resource to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: JobScheduleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Stream Analytics Job Schedule.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_account = azure.storage.Account("example",
            name="example",
            resource_group_name=example.name,
            location=example.location,
            account_tier="Standard",
            account_replication_type="LRS")
        example_container = azure.storage.Container("example",
            name="example",
            storage_account_name=example_account.name,
            container_access_type="private")
        example_blob = azure.storage.Blob("example",
            name="example",
            storage_account_name=example_account.name,
            storage_container_name=example_container.name,
            type="Block",
            source=pulumi.FileAsset("example.csv"))
        example_job = azure.streamanalytics.Job("example",
            name="example-job",
            resource_group_name=example.name,
            location=example.location,
            compatibility_level="1.2",
            data_locale="en-GB",
            events_late_arrival_max_delay_in_seconds=60,
            events_out_of_order_max_delay_in_seconds=50,
            events_out_of_order_policy="Adjust",
            output_error_policy="Drop",
            streaming_units=3,
            tags={
                "environment": "Example",
            },
            transformation_query=\"\"\"    SELECT *
            INTO [exampleoutput]
            FROM [exampleinput]
        \"\"\")
        example_stream_input_blob = azure.streamanalytics.StreamInputBlob("example",
            name="exampleinput",
            stream_analytics_job_name=example_job.name,
            resource_group_name=example_job.resource_group_name,
            storage_account_name=example_account.name,
            storage_account_key=example_account.primary_access_key,
            storage_container_name=example_container.name,
            path_pattern="",
            date_format="yyyy/MM/dd",
            time_format="HH",
            serialization={
                "type": "Csv",
                "encoding": "UTF8",
                "field_delimiter": ",",
            })
        example_output_blob = azure.streamanalytics.OutputBlob("example",
            name="exampleoutput",
            stream_analytics_job_name=example_job.name,
            resource_group_name=example_job.resource_group_name,
            storage_account_name=example_account.name,
            storage_account_key=example_account.primary_access_key,
            storage_container_name=example_container.name,
            path_pattern="example-{date}-{time}",
            date_format="yyyy-MM-dd",
            time_format="HH",
            serialization={
                "type": "Avro",
            })
        example_job_schedule = azure.streamanalytics.JobSchedule("example",
            stream_analytics_job_id=example_job.id,
            start_mode="CustomTime",
            start_time="2022-09-21T00:00:00Z",
            opts = pulumi.ResourceOptions(depends_on=[
                    example_job,
                    example_stream_input_blob,
                    example_output_blob,
                ]))
        ```

        ## Import

        Stream Analytics Job's can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:streamanalytics/jobSchedule:JobSchedule example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.StreamAnalytics/streamingJobs/job1/schedule/default
        ```

        :param str resource_name: The name of the resource.
        :param JobScheduleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(JobScheduleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 start_mode: Optional[pulumi.Input[str]] = None,
                 start_time: Optional[pulumi.Input[str]] = None,
                 stream_analytics_job_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = JobScheduleArgs.__new__(JobScheduleArgs)

            if start_mode is None and not opts.urn:
                raise TypeError("Missing required property 'start_mode'")
            __props__.__dict__["start_mode"] = start_mode
            __props__.__dict__["start_time"] = start_time
            if stream_analytics_job_id is None and not opts.urn:
                raise TypeError("Missing required property 'stream_analytics_job_id'")
            __props__.__dict__["stream_analytics_job_id"] = stream_analytics_job_id
            __props__.__dict__["last_output_time"] = None
        super(JobSchedule, __self__).__init__(
            'azure:streamanalytics/jobSchedule:JobSchedule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            last_output_time: Optional[pulumi.Input[str]] = None,
            start_mode: Optional[pulumi.Input[str]] = None,
            start_time: Optional[pulumi.Input[str]] = None,
            stream_analytics_job_id: Optional[pulumi.Input[str]] = None) -> 'JobSchedule':
        """
        Get an existing JobSchedule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] last_output_time: The time at which the Stream Analytics job last produced an output.
        :param pulumi.Input[str] start_mode: The starting mode of the Stream Analytics Job. Possible values are `JobStartTime`, `CustomTime` and `LastOutputEventTime`.
               
               > **Note:** Setting `start_mode` to `LastOutputEventTime` is only possible if the job had been previously started and produced output.
        :param pulumi.Input[str] start_time: The time in ISO8601 format at which the Stream Analytics Job should be started e.g. `2022-04-01T00:00:00Z`. This property can only be specified if `start_mode` is set to `CustomTime`
        :param pulumi.Input[str] stream_analytics_job_id: The ID of the Stream Analytics Job that should be scheduled or started. Changing this forces a new resource to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _JobScheduleState.__new__(_JobScheduleState)

        __props__.__dict__["last_output_time"] = last_output_time
        __props__.__dict__["start_mode"] = start_mode
        __props__.__dict__["start_time"] = start_time
        __props__.__dict__["stream_analytics_job_id"] = stream_analytics_job_id
        return JobSchedule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="lastOutputTime")
    def last_output_time(self) -> pulumi.Output[str]:
        """
        The time at which the Stream Analytics job last produced an output.
        """
        return pulumi.get(self, "last_output_time")

    @property
    @pulumi.getter(name="startMode")
    def start_mode(self) -> pulumi.Output[str]:
        """
        The starting mode of the Stream Analytics Job. Possible values are `JobStartTime`, `CustomTime` and `LastOutputEventTime`.

        > **Note:** Setting `start_mode` to `LastOutputEventTime` is only possible if the job had been previously started and produced output.
        """
        return pulumi.get(self, "start_mode")

    @property
    @pulumi.getter(name="startTime")
    def start_time(self) -> pulumi.Output[str]:
        """
        The time in ISO8601 format at which the Stream Analytics Job should be started e.g. `2022-04-01T00:00:00Z`. This property can only be specified if `start_mode` is set to `CustomTime`
        """
        return pulumi.get(self, "start_time")

    @property
    @pulumi.getter(name="streamAnalyticsJobId")
    def stream_analytics_job_id(self) -> pulumi.Output[str]:
        """
        The ID of the Stream Analytics Job that should be scheduled or started. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "stream_analytics_job_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['SqlDedicatedGatewayArgs', 'SqlDedicatedGateway']

@pulumi.input_type
class SqlDedicatedGatewayArgs:
    def __init__(__self__, *,
                 cosmosdb_account_id: pulumi.Input[str],
                 instance_count: pulumi.Input[int],
                 instance_size: pulumi.Input[str]):
        """
        The set of arguments for constructing a SqlDedicatedGateway resource.
        :param pulumi.Input[str] cosmosdb_account_id: The resource ID of the CosmosDB Account. Changing this forces a new resource to be created.
        :param pulumi.Input[int] instance_count: The instance count for the CosmosDB SQL Dedicated Gateway. Possible value is between `1` and `5`.
        :param pulumi.Input[str] instance_size: The instance size for the CosmosDB SQL Dedicated Gateway. Changing this forces a new resource to be created. Possible values are `Cosmos.D4s`, `Cosmos.D8s` and `Cosmos.D16s`.
        """
        pulumi.set(__self__, "cosmosdb_account_id", cosmosdb_account_id)
        pulumi.set(__self__, "instance_count", instance_count)
        pulumi.set(__self__, "instance_size", instance_size)

    @property
    @pulumi.getter(name="cosmosdbAccountId")
    def cosmosdb_account_id(self) -> pulumi.Input[str]:
        """
        The resource ID of the CosmosDB Account. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "cosmosdb_account_id")

    @cosmosdb_account_id.setter
    def cosmosdb_account_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "cosmosdb_account_id", value)

    @property
    @pulumi.getter(name="instanceCount")
    def instance_count(self) -> pulumi.Input[int]:
        """
        The instance count for the CosmosDB SQL Dedicated Gateway. Possible value is between `1` and `5`.
        """
        return pulumi.get(self, "instance_count")

    @instance_count.setter
    def instance_count(self, value: pulumi.Input[int]):
        pulumi.set(self, "instance_count", value)

    @property
    @pulumi.getter(name="instanceSize")
    def instance_size(self) -> pulumi.Input[str]:
        """
        The instance size for the CosmosDB SQL Dedicated Gateway. Changing this forces a new resource to be created. Possible values are `Cosmos.D4s`, `Cosmos.D8s` and `Cosmos.D16s`.
        """
        return pulumi.get(self, "instance_size")

    @instance_size.setter
    def instance_size(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_size", value)


@pulumi.input_type
class _SqlDedicatedGatewayState:
    def __init__(__self__, *,
                 cosmosdb_account_id: Optional[pulumi.Input[str]] = None,
                 instance_count: Optional[pulumi.Input[int]] = None,
                 instance_size: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering SqlDedicatedGateway resources.
        :param pulumi.Input[str] cosmosdb_account_id: The resource ID of the CosmosDB Account. Changing this forces a new resource to be created.
        :param pulumi.Input[int] instance_count: The instance count for the CosmosDB SQL Dedicated Gateway. Possible value is between `1` and `5`.
        :param pulumi.Input[str] instance_size: The instance size for the CosmosDB SQL Dedicated Gateway. Changing this forces a new resource to be created. Possible values are `Cosmos.D4s`, `Cosmos.D8s` and `Cosmos.D16s`.
        """
        if cosmosdb_account_id is not None:
            pulumi.set(__self__, "cosmosdb_account_id", cosmosdb_account_id)
        if instance_count is not None:
            pulumi.set(__self__, "instance_count", instance_count)
        if instance_size is not None:
            pulumi.set(__self__, "instance_size", instance_size)

    @property
    @pulumi.getter(name="cosmosdbAccountId")
    def cosmosdb_account_id(self) -> Optional[pulumi.Input[str]]:
        """
        The resource ID of the CosmosDB Account. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "cosmosdb_account_id")

    @cosmosdb_account_id.setter
    def cosmosdb_account_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cosmosdb_account_id", value)

    @property
    @pulumi.getter(name="instanceCount")
    def instance_count(self) -> Optional[pulumi.Input[int]]:
        """
        The instance count for the CosmosDB SQL Dedicated Gateway. Possible value is between `1` and `5`.
        """
        return pulumi.get(self, "instance_count")

    @instance_count.setter
    def instance_count(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "instance_count", value)

    @property
    @pulumi.getter(name="instanceSize")
    def instance_size(self) -> Optional[pulumi.Input[str]]:
        """
        The instance size for the CosmosDB SQL Dedicated Gateway. Changing this forces a new resource to be created. Possible values are `Cosmos.D4s`, `Cosmos.D8s` and `Cosmos.D16s`.
        """
        return pulumi.get(self, "instance_size")

    @instance_size.setter
    def instance_size(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_size", value)


class SqlDedicatedGateway(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cosmosdb_account_id: Optional[pulumi.Input[str]] = None,
                 instance_count: Optional[pulumi.Input[int]] = None,
                 instance_size: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a SQL Dedicated Gateway within a Cosmos DB Account.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resource-group",
            location="West Europe")
        example_account = azure.cosmosdb.Account("example",
            name="example-ca",
            location=example.location,
            resource_group_name=example.name,
            offer_type="Standard",
            kind="GlobalDocumentDB",
            consistency_policy={
                "consistency_level": "BoundedStaleness",
            },
            geo_locations=[{
                "location": example.location,
                "failover_priority": 0,
            }])
        example_sql_dedicated_gateway = azure.cosmosdb.SqlDedicatedGateway("example",
            cosmosdb_account_id=example_account.id,
            instance_count=1,
            instance_size="Cosmos.D4s")
        ```

        ## Import

        CosmosDB SQL Dedicated Gateways can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:cosmosdb/sqlDedicatedGateway:SqlDedicatedGateway example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup1/providers/Microsoft.DocumentDB/databaseAccounts/account1/services/SqlDedicatedGateway
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cosmosdb_account_id: The resource ID of the CosmosDB Account. Changing this forces a new resource to be created.
        :param pulumi.Input[int] instance_count: The instance count for the CosmosDB SQL Dedicated Gateway. Possible value is between `1` and `5`.
        :param pulumi.Input[str] instance_size: The instance size for the CosmosDB SQL Dedicated Gateway. Changing this forces a new resource to be created. Possible values are `Cosmos.D4s`, `Cosmos.D8s` and `Cosmos.D16s`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SqlDedicatedGatewayArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a SQL Dedicated Gateway within a Cosmos DB Account.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resource-group",
            location="West Europe")
        example_account = azure.cosmosdb.Account("example",
            name="example-ca",
            location=example.location,
            resource_group_name=example.name,
            offer_type="Standard",
            kind="GlobalDocumentDB",
            consistency_policy={
                "consistency_level": "BoundedStaleness",
            },
            geo_locations=[{
                "location": example.location,
                "failover_priority": 0,
            }])
        example_sql_dedicated_gateway = azure.cosmosdb.SqlDedicatedGateway("example",
            cosmosdb_account_id=example_account.id,
            instance_count=1,
            instance_size="Cosmos.D4s")
        ```

        ## Import

        CosmosDB SQL Dedicated Gateways can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:cosmosdb/sqlDedicatedGateway:SqlDedicatedGateway example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup1/providers/Microsoft.DocumentDB/databaseAccounts/account1/services/SqlDedicatedGateway
        ```

        :param str resource_name: The name of the resource.
        :param SqlDedicatedGatewayArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SqlDedicatedGatewayArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cosmosdb_account_id: Optional[pulumi.Input[str]] = None,
                 instance_count: Optional[pulumi.Input[int]] = None,
                 instance_size: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SqlDedicatedGatewayArgs.__new__(SqlDedicatedGatewayArgs)

            if cosmosdb_account_id is None and not opts.urn:
                raise TypeError("Missing required property 'cosmosdb_account_id'")
            __props__.__dict__["cosmosdb_account_id"] = cosmosdb_account_id
            if instance_count is None and not opts.urn:
                raise TypeError("Missing required property 'instance_count'")
            __props__.__dict__["instance_count"] = instance_count
            if instance_size is None and not opts.urn:
                raise TypeError("Missing required property 'instance_size'")
            __props__.__dict__["instance_size"] = instance_size
        super(SqlDedicatedGateway, __self__).__init__(
            'azure:cosmosdb/sqlDedicatedGateway:SqlDedicatedGateway',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cosmosdb_account_id: Optional[pulumi.Input[str]] = None,
            instance_count: Optional[pulumi.Input[int]] = None,
            instance_size: Optional[pulumi.Input[str]] = None) -> 'SqlDedicatedGateway':
        """
        Get an existing SqlDedicatedGateway resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cosmosdb_account_id: The resource ID of the CosmosDB Account. Changing this forces a new resource to be created.
        :param pulumi.Input[int] instance_count: The instance count for the CosmosDB SQL Dedicated Gateway. Possible value is between `1` and `5`.
        :param pulumi.Input[str] instance_size: The instance size for the CosmosDB SQL Dedicated Gateway. Changing this forces a new resource to be created. Possible values are `Cosmos.D4s`, `Cosmos.D8s` and `Cosmos.D16s`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SqlDedicatedGatewayState.__new__(_SqlDedicatedGatewayState)

        __props__.__dict__["cosmosdb_account_id"] = cosmosdb_account_id
        __props__.__dict__["instance_count"] = instance_count
        __props__.__dict__["instance_size"] = instance_size
        return SqlDedicatedGateway(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="cosmosdbAccountId")
    def cosmosdb_account_id(self) -> pulumi.Output[str]:
        """
        The resource ID of the CosmosDB Account. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "cosmosdb_account_id")

    @property
    @pulumi.getter(name="instanceCount")
    def instance_count(self) -> pulumi.Output[int]:
        """
        The instance count for the CosmosDB SQL Dedicated Gateway. Possible value is between `1` and `5`.
        """
        return pulumi.get(self, "instance_count")

    @property
    @pulumi.getter(name="instanceSize")
    def instance_size(self) -> pulumi.Output[str]:
        """
        The instance size for the CosmosDB SQL Dedicated Gateway. Changing this forces a new resource to be created. Possible values are `Cosmos.D4s`, `Cosmos.D8s` and `Cosmos.D16s`.
        """
        return pulumi.get(self, "instance_size")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .get_local_rulestack import *
from .local_rulestack import *
from .local_rulestack_certificate import *
from .local_rulestack_fqdn_list import *
from .local_rulestack_outbound_trust_certificate_association import *
from .local_rulestack_outbound_untrust_certificate_association import *
from .local_rulestack_prefix_list import *
from .local_rulestack_rule import *
from .next_generation_firewall_virtual_hub_local_rulestack import *
from .next_generation_firewall_virtual_hub_panorama import *
from .next_generation_firewall_virtual_network_local_rulestack import *
from .next_generation_firewall_virtual_network_panorama import *
from .virtual_network_appliance import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['FrontdoorRuleArgs', 'FrontdoorRule']

@pulumi.input_type
class FrontdoorRuleArgs:
    def __init__(__self__, *,
                 actions: pulumi.Input['FrontdoorRuleActionsArgs'],
                 cdn_frontdoor_rule_set_id: pulumi.Input[str],
                 order: pulumi.Input[int],
                 behavior_on_match: Optional[pulumi.Input[str]] = None,
                 conditions: Optional[pulumi.Input['FrontdoorRuleConditionsArgs']] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a FrontdoorRule resource.
        :param pulumi.Input['FrontdoorRuleActionsArgs'] actions: An `actions` block as defined below.
        :param pulumi.Input[str] cdn_frontdoor_rule_set_id: The resource ID of the Front Door Rule Set for this Front Door Rule. Changing this forces a new Front Door Rule to be created.
        :param pulumi.Input[int] order: The order in which the rules will be applied for the Front Door Endpoint. The order value should be sequential and begin at `1`(e.g. `1`, `2`, `3`...). A Front Door Rule with a lesser order value will be applied before a rule with a greater order value.
               
               ->**NOTE:** If the Front Door Rule has an order value of `0` they do not require any conditions and the actions will always be applied.
        :param pulumi.Input[str] behavior_on_match: If this rule is a match should the rules engine continue processing the remaining rules or stop? Possible values are `Continue` and `Stop`. Defaults to `Continue`.
        :param pulumi.Input['FrontdoorRuleConditionsArgs'] conditions: A `conditions` block as defined below.
        :param pulumi.Input[str] name: The name which should be used for this Front Door Rule. Possible values must be between 1 and 260 characters in length, begin with a letter and may contain only letters and numbers. Changing this forces a new Front Door Rule to be created.
        """
        pulumi.set(__self__, "actions", actions)
        pulumi.set(__self__, "cdn_frontdoor_rule_set_id", cdn_frontdoor_rule_set_id)
        pulumi.set(__self__, "order", order)
        if behavior_on_match is not None:
            pulumi.set(__self__, "behavior_on_match", behavior_on_match)
        if conditions is not None:
            pulumi.set(__self__, "conditions", conditions)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def actions(self) -> pulumi.Input['FrontdoorRuleActionsArgs']:
        """
        An `actions` block as defined below.
        """
        return pulumi.get(self, "actions")

    @actions.setter
    def actions(self, value: pulumi.Input['FrontdoorRuleActionsArgs']):
        pulumi.set(self, "actions", value)

    @property
    @pulumi.getter(name="cdnFrontdoorRuleSetId")
    def cdn_frontdoor_rule_set_id(self) -> pulumi.Input[str]:
        """
        The resource ID of the Front Door Rule Set for this Front Door Rule. Changing this forces a new Front Door Rule to be created.
        """
        return pulumi.get(self, "cdn_frontdoor_rule_set_id")

    @cdn_frontdoor_rule_set_id.setter
    def cdn_frontdoor_rule_set_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "cdn_frontdoor_rule_set_id", value)

    @property
    @pulumi.getter
    def order(self) -> pulumi.Input[int]:
        """
        The order in which the rules will be applied for the Front Door Endpoint. The order value should be sequential and begin at `1`(e.g. `1`, `2`, `3`...). A Front Door Rule with a lesser order value will be applied before a rule with a greater order value.

        ->**NOTE:** If the Front Door Rule has an order value of `0` they do not require any conditions and the actions will always be applied.
        """
        return pulumi.get(self, "order")

    @order.setter
    def order(self, value: pulumi.Input[int]):
        pulumi.set(self, "order", value)

    @property
    @pulumi.getter(name="behaviorOnMatch")
    def behavior_on_match(self) -> Optional[pulumi.Input[str]]:
        """
        If this rule is a match should the rules engine continue processing the remaining rules or stop? Possible values are `Continue` and `Stop`. Defaults to `Continue`.
        """
        return pulumi.get(self, "behavior_on_match")

    @behavior_on_match.setter
    def behavior_on_match(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "behavior_on_match", value)

    @property
    @pulumi.getter
    def conditions(self) -> Optional[pulumi.Input['FrontdoorRuleConditionsArgs']]:
        """
        A `conditions` block as defined below.
        """
        return pulumi.get(self, "conditions")

    @conditions.setter
    def conditions(self, value: Optional[pulumi.Input['FrontdoorRuleConditionsArgs']]):
        pulumi.set(self, "conditions", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name which should be used for this Front Door Rule. Possible values must be between 1 and 260 characters in length, begin with a letter and may contain only letters and numbers. Changing this forces a new Front Door Rule to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _FrontdoorRuleState:
    def __init__(__self__, *,
                 actions: Optional[pulumi.Input['FrontdoorRuleActionsArgs']] = None,
                 behavior_on_match: Optional[pulumi.Input[str]] = None,
                 cdn_frontdoor_rule_set_id: Optional[pulumi.Input[str]] = None,
                 cdn_frontdoor_rule_set_name: Optional[pulumi.Input[str]] = None,
                 conditions: Optional[pulumi.Input['FrontdoorRuleConditionsArgs']] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 order: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering FrontdoorRule resources.
        :param pulumi.Input['FrontdoorRuleActionsArgs'] actions: An `actions` block as defined below.
        :param pulumi.Input[str] behavior_on_match: If this rule is a match should the rules engine continue processing the remaining rules or stop? Possible values are `Continue` and `Stop`. Defaults to `Continue`.
        :param pulumi.Input[str] cdn_frontdoor_rule_set_id: The resource ID of the Front Door Rule Set for this Front Door Rule. Changing this forces a new Front Door Rule to be created.
        :param pulumi.Input[str] cdn_frontdoor_rule_set_name: The name of the Front Door Rule Set containing this Front Door Rule.
        :param pulumi.Input['FrontdoorRuleConditionsArgs'] conditions: A `conditions` block as defined below.
        :param pulumi.Input[str] name: The name which should be used for this Front Door Rule. Possible values must be between 1 and 260 characters in length, begin with a letter and may contain only letters and numbers. Changing this forces a new Front Door Rule to be created.
        :param pulumi.Input[int] order: The order in which the rules will be applied for the Front Door Endpoint. The order value should be sequential and begin at `1`(e.g. `1`, `2`, `3`...). A Front Door Rule with a lesser order value will be applied before a rule with a greater order value.
               
               ->**NOTE:** If the Front Door Rule has an order value of `0` they do not require any conditions and the actions will always be applied.
        """
        if actions is not None:
            pulumi.set(__self__, "actions", actions)
        if behavior_on_match is not None:
            pulumi.set(__self__, "behavior_on_match", behavior_on_match)
        if cdn_frontdoor_rule_set_id is not None:
            pulumi.set(__self__, "cdn_frontdoor_rule_set_id", cdn_frontdoor_rule_set_id)
        if cdn_frontdoor_rule_set_name is not None:
            pulumi.set(__self__, "cdn_frontdoor_rule_set_name", cdn_frontdoor_rule_set_name)
        if conditions is not None:
            pulumi.set(__self__, "conditions", conditions)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if order is not None:
            pulumi.set(__self__, "order", order)

    @property
    @pulumi.getter
    def actions(self) -> Optional[pulumi.Input['FrontdoorRuleActionsArgs']]:
        """
        An `actions` block as defined below.
        """
        return pulumi.get(self, "actions")

    @actions.setter
    def actions(self, value: Optional[pulumi.Input['FrontdoorRuleActionsArgs']]):
        pulumi.set(self, "actions", value)

    @property
    @pulumi.getter(name="behaviorOnMatch")
    def behavior_on_match(self) -> Optional[pulumi.Input[str]]:
        """
        If this rule is a match should the rules engine continue processing the remaining rules or stop? Possible values are `Continue` and `Stop`. Defaults to `Continue`.
        """
        return pulumi.get(self, "behavior_on_match")

    @behavior_on_match.setter
    def behavior_on_match(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "behavior_on_match", value)

    @property
    @pulumi.getter(name="cdnFrontdoorRuleSetId")
    def cdn_frontdoor_rule_set_id(self) -> Optional[pulumi.Input[str]]:
        """
        The resource ID of the Front Door Rule Set for this Front Door Rule. Changing this forces a new Front Door Rule to be created.
        """
        return pulumi.get(self, "cdn_frontdoor_rule_set_id")

    @cdn_frontdoor_rule_set_id.setter
    def cdn_frontdoor_rule_set_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cdn_frontdoor_rule_set_id", value)

    @property
    @pulumi.getter(name="cdnFrontdoorRuleSetName")
    def cdn_frontdoor_rule_set_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Front Door Rule Set containing this Front Door Rule.
        """
        return pulumi.get(self, "cdn_frontdoor_rule_set_name")

    @cdn_frontdoor_rule_set_name.setter
    def cdn_frontdoor_rule_set_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cdn_frontdoor_rule_set_name", value)

    @property
    @pulumi.getter
    def conditions(self) -> Optional[pulumi.Input['FrontdoorRuleConditionsArgs']]:
        """
        A `conditions` block as defined below.
        """
        return pulumi.get(self, "conditions")

    @conditions.setter
    def conditions(self, value: Optional[pulumi.Input['FrontdoorRuleConditionsArgs']]):
        pulumi.set(self, "conditions", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name which should be used for this Front Door Rule. Possible values must be between 1 and 260 characters in length, begin with a letter and may contain only letters and numbers. Changing this forces a new Front Door Rule to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def order(self) -> Optional[pulumi.Input[int]]:
        """
        The order in which the rules will be applied for the Front Door Endpoint. The order value should be sequential and begin at `1`(e.g. `1`, `2`, `3`...). A Front Door Rule with a lesser order value will be applied before a rule with a greater order value.

        ->**NOTE:** If the Front Door Rule has an order value of `0` they do not require any conditions and the actions will always be applied.
        """
        return pulumi.get(self, "order")

    @order.setter
    def order(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "order", value)


class FrontdoorRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 actions: Optional[pulumi.Input[Union['FrontdoorRuleActionsArgs', 'FrontdoorRuleActionsArgsDict']]] = None,
                 behavior_on_match: Optional[pulumi.Input[str]] = None,
                 cdn_frontdoor_rule_set_id: Optional[pulumi.Input[str]] = None,
                 conditions: Optional[pulumi.Input[Union['FrontdoorRuleConditionsArgs', 'FrontdoorRuleConditionsArgsDict']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 order: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        Manages a Front Door (standard/premium) Rule.

        !>**IMPORTANT:** The Rules resource **must** include a `depends_on` meta-argument which references the `cdn.FrontdoorOrigin` and the `cdn.FrontdoorOriginGroup`.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-cdn-frontdoor",
            location="West Europe")
        example_frontdoor_profile = azure.cdn.FrontdoorProfile("example",
            name="example-profile",
            resource_group_name=example.name,
            sku_name="Premium_AzureFrontDoor")
        example_frontdoor_endpoint = azure.cdn.FrontdoorEndpoint("example",
            name="example-endpoint",
            cdn_frontdoor_profile_id=example_frontdoor_profile.id,
            tags={
                "endpoint": "contoso.com",
            })
        example_frontdoor_origin_group = azure.cdn.FrontdoorOriginGroup("example",
            name="example-originGroup",
            cdn_frontdoor_profile_id=example_frontdoor_profile.id,
            session_affinity_enabled=True,
            restore_traffic_time_to_healed_or_new_endpoint_in_minutes=10,
            health_probe={
                "interval_in_seconds": 240,
                "path": "/healthProbe",
                "protocol": "Https",
                "request_type": "GET",
            },
            load_balancing={
                "additional_latency_in_milliseconds": 0,
                "sample_size": 16,
                "successful_samples_required": 3,
            })
        example_frontdoor_origin = azure.cdn.FrontdoorOrigin("example",
            name="example-origin",
            cdn_frontdoor_origin_group_id=example_frontdoor_origin_group.id,
            enabled=True,
            certificate_name_check_enabled=False,
            host_name=example_frontdoor_endpoint.host_name,
            http_port=80,
            https_port=443,
            origin_host_header="contoso.com",
            priority=1,
            weight=500)
        example_frontdoor_rule_set = azure.cdn.FrontdoorRuleSet("example",
            name="exampleruleset",
            cdn_frontdoor_profile_id=example_frontdoor_profile.id)
        example_frontdoor_rule = azure.cdn.FrontdoorRule("example",
            name="examplerule",
            cdn_frontdoor_rule_set_id=example_frontdoor_rule_set.id,
            order=1,
            behavior_on_match="Continue",
            actions={
                "route_configuration_override_action": {
                    "cdn_frontdoor_origin_group_id": example_frontdoor_origin_group.id,
                    "forwarding_protocol": "HttpsOnly",
                    "query_string_caching_behavior": "IncludeSpecifiedQueryStrings",
                    "query_string_parameters": [
                        "foo",
                        "clientIp={client_ip}",
                    ],
                    "compression_enabled": True,
                    "cache_behavior": "OverrideIfOriginMissing",
                    "cache_duration": "365.23:59:59",
                },
                "url_redirect_action": {
                    "redirect_type": "PermanentRedirect",
                    "redirect_protocol": "MatchRequest",
                    "query_string": "clientIp={client_ip}",
                    "destination_path": "/exampleredirection",
                    "destination_hostname": "contoso.com",
                    "destination_fragment": "UrlRedirect",
                },
            },
            conditions={
                "host_name_conditions": [{
                    "operator": "Equal",
                    "negate_condition": False,
                    "match_values": [
                        "www.contoso.com",
                        "images.contoso.com",
                        "video.contoso.com",
                    ],
                    "transforms": [
                        "Lowercase",
                        "Trim",
                    ],
                }],
                "is_device_conditions": [{
                    "operator": "Equal",
                    "negate_condition": False,
                    "match_values": "Mobile",
                }],
                "post_args_conditions": [{
                    "post_args_name": "customerName",
                    "operator": "BeginsWith",
                    "match_values": [
                        "J",
                        "K",
                    ],
                    "transforms": ["Uppercase"],
                }],
                "request_method_conditions": [{
                    "operator": "Equal",
                    "negate_condition": False,
                    "match_values": ["DELETE"],
                }],
                "url_filename_conditions": [{
                    "operator": "Equal",
                    "negate_condition": False,
                    "match_values": ["media.mp4"],
                    "transforms": [
                        "Lowercase",
                        "RemoveNulls",
                        "Trim",
                    ],
                }],
            },
            opts = pulumi.ResourceOptions(depends_on=[
                    example_frontdoor_origin_group,
                    example_frontdoor_origin,
                ]))
        ```

        ## Specifying IP Address Ranges

        When specifying IP address ranges in the `socket_address_condition` and the `remote_address_condition` `match_values` use the following format:

        Use `CIDR` notation when specifying IP address blocks. This means that the syntax for an IP address block is the base IP address followed by a forward slash and the prefix size For example:

        * `IPv4` example: `5.5.5.64/26` matches any requests that arrive from addresses `5.5.5.64` through `5.5.5.127`.
        * `IPv6` example: `1:2:3:/48` matches any requests that arrive from addresses `1:2:3:0:0:0:0:0` through `1:2:3:ffff:ffff:ffff:ffff:ffff`.

        When you specify multiple IP addresses and IP address blocks, `OR` logic is applied.

        * `IPv4` example: if you add two IP addresses `1.2.3.4` and `10.20.30.40`, the condition is matched for any requests that arrive from either address `1.2.3.4` or `10.20.30.40`.
        * `IPv6` example: if you add two IP addresses `1:2:3:4:5:6:7:8` and `10:20:30:40:50:60:70:80`, the condition is matched for any requests that arrive from either address `1:2:3:4:5:6:7:8` or `10:20:30:40:50:60:70:80`.

        ***

        ## Action Server Variables

        Rule Set server variables provide access to structured information about the request. You can use server variables to dynamically change the request/response headers or URL rewrite paths/query strings, for example, when a new page load or when a form is posted.

        ### Supported Action Server Variables

        | Variable name | Description |
        |---------------|-------------|
        | `socket_ip`      | The IP address of the direct connection to Front Door Profiles edge. If the client used an HTTP proxy or a load balancer to send the request, the value of `socket_ip` is the IP address of the proxy or load balancer. |
        | `client_ip`      | The IP address of the client that made the original request. If there was an `X-Forwarded-For` header in the request, then the client IP address is picked from the header. |
        | `client_port`    | The IP port of the client that made the request. |
        | `hostname`       | The host name in the request from the client. |
        | `geo_country`    | Indicates the requester's country/region of origin through its country/region code. |
        | `http_method`    | The method used to make the URL request, such as `GET` or `POST`. |
        | `http_version`   | The request protocol. Usually `HTTP/1.0`, `HTTP/1.1`, or `HTTP/2.0`. |
        | `query_string`   | The list of variable/value pairs that follows the "?" in the requested URL. For example, in the request `http://contoso.com:8080/article.aspx?id=123&title=fabrikam`, the `query_string` value will be `id=123&title=fabrikam`. |
        | `request_scheme` | The request scheme: `http` or `https`. |
        | `request_uri`    | The full original request URI (with arguments). For example, in the request `http://contoso.com:8080/article.aspx?id=123&title=fabrikam`, the `request_uri` value will be `/article.aspx?id=123&title=fabrikam`. |
        | `ssl_protocol`   | The protocol of an established TLS connection. |
        | `server_port`    | The port of the server that accepted a request. |
        | `url_path`       | Identifies the specific resource in the host that the web client wants to access. This is the part of the request URI without the arguments. For example, in the request `http://contoso.com:8080/article.aspx?id=123&title=fabrikam`, the `uri_path` value will be `/article.aspx`. |

        ### Action Server Variable Format

        Server variables can be specified using the following formats:

        * `{variable}` - Include the entire server variable. For example, if the client IP address is `111.222.333.444` then the `{client_ip}` token would evaluate to `111.222.333.444`.

        * `{variable:offset}` - Include the server variable after a specific offset, until the end of the variable. The offset is zero-based. For example, if the client IP address is `111.222.333.444` then the `{client_ip:3}` token would evaluate to `.222.333.444`.

        * `{variable:offset:length}` - Include the server variable after a specific offset, up to the specified length. The offset is zero-based. For example, if the client IP address is `111.222.333.444` then the `{client_ip:4:3}` token would evaluate to `222`.

        ### Action Server Variables Support

        Action Server variables are supported on the following actions:

        * `route_configuration_override_action`
        * `request_header_action`
        * `response_header_action`
        * `url_redirect_action`
        * `url_rewrite_action`

        ***

        ## Condition Operator list

        For rules that accept values from the standard operator list, the following operators are valid:

        | Operator                   | Description | Condition Value |
        |----------------------------|-------------|-----------------|
        | Any                        |Matches when there is any value, regardless of what it is. | Any |
        | Equal                      | Matches when the value exactly matches the specified string. | Equal |
        | Contains                   | Matches when the value contains the specified string. | Contains |
        | Less Than                  | Matches when the length of the value is less than the specified integer. | LessThan |
        | Greater Than               | Matches when the length of the value is greater than the specified integer. | GreaterThan |
        | Less Than or Equal         | Matches when the length of the value is less than or equal to the specified integer. | LessThanOrEqual |
        | Greater Than or Equal      | Matches when the length of the value is greater than or equal to the specified integer. | GreaterThanOrEqual |
        | Begins With                | Matches when the value begins with the specified string. | BeginsWith |
        | Ends With                  | Matches when the value ends with the specified string. | EndsWith |
        | RegEx                      | Matches when the value matches the specified regular expression. See below for further details. | RegEx |
        | Not Any                    | Matches when there is no value. | Any and negateCondition = true |
        | Not Equal                  | Matches when the value does not match the specified string. | Equal and negateCondition : true |
        | Not Contains               | Matches when the value does not contain the specified string. | Contains and negateCondition = true |
        | Not Less Than              | Matches when the length of the value is not less than the specified integer. | LessThan and negateCondition = true |
        | Not Greater Than           | Matches when the length of the value is not greater than the specified integer. | GreaterThan and negateCondition = true |
        | Not Less Than or Equal     | Matches when the length of the value is not less than or equal to the specified integer. | LessThanOrEqual and negateCondition = true |
        | Not Greater Than or Equals | Matches when the length of the value is not greater than or equal to the specified integer. | GreaterThanOrEqual and negateCondition = true |
        | Not Begins With            | Matches when the value does not begin with the specified string. | BeginsWith and negateCondition = true |
        | Not Ends With              | Matches when the value does not end with the specified string. | EndsWith and negateCondition = true |
        | Not RegEx                  | Matches when the value does not match the specified regular expression. See `Condition Regular Expressions` for further details. | RegEx and negateCondition = true |

        ***

        ## Condition Regular Expressions

        Regular expressions **don't** support the following operations:

        * Backreferences and capturing subexpressions.
        * Arbitrary zero-width assertions.
        * Subroutine references and recursive patterns.
        * Conditional patterns.
        * Backtracking control verbs.
        * The `\\C` single-byte directive.
        * The `\\R` newline match directive.
        * The `\\K` start of match reset directive.
        * Callouts and embedded code.
        * Atomic grouping and possessive quantifiers.

        ***

        ## Condition Transform List

        For rules that can transform strings, the following transforms are valid:

        | Transform   | Description |
        |-------------|-------------|
        | Lowercase   | Converts the string to the lowercase representation. |
        | Uppercase   | Converts the string to the uppercase representation. |
        | Trim        | Trims leading and trailing whitespace from the string. |
        | RemoveNulls | Removes null values from the string. |
        | URLEncode   | URL-encodes the string. |
        | URLDecode   | URL-decodes the string. |

        ***

        ## Import

        Front Door Rules can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:cdn/frontdoorRule:FrontdoorRule example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup1/providers/Microsoft.Cdn/profiles/profile1/ruleSets/ruleSet1/rules/rule1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['FrontdoorRuleActionsArgs', 'FrontdoorRuleActionsArgsDict']] actions: An `actions` block as defined below.
        :param pulumi.Input[str] behavior_on_match: If this rule is a match should the rules engine continue processing the remaining rules or stop? Possible values are `Continue` and `Stop`. Defaults to `Continue`.
        :param pulumi.Input[str] cdn_frontdoor_rule_set_id: The resource ID of the Front Door Rule Set for this Front Door Rule. Changing this forces a new Front Door Rule to be created.
        :param pulumi.Input[Union['FrontdoorRuleConditionsArgs', 'FrontdoorRuleConditionsArgsDict']] conditions: A `conditions` block as defined below.
        :param pulumi.Input[str] name: The name which should be used for this Front Door Rule. Possible values must be between 1 and 260 characters in length, begin with a letter and may contain only letters and numbers. Changing this forces a new Front Door Rule to be created.
        :param pulumi.Input[int] order: The order in which the rules will be applied for the Front Door Endpoint. The order value should be sequential and begin at `1`(e.g. `1`, `2`, `3`...). A Front Door Rule with a lesser order value will be applied before a rule with a greater order value.
               
               ->**NOTE:** If the Front Door Rule has an order value of `0` they do not require any conditions and the actions will always be applied.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FrontdoorRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Front Door (standard/premium) Rule.

        !>**IMPORTANT:** The Rules resource **must** include a `depends_on` meta-argument which references the `cdn.FrontdoorOrigin` and the `cdn.FrontdoorOriginGroup`.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-cdn-frontdoor",
            location="West Europe")
        example_frontdoor_profile = azure.cdn.FrontdoorProfile("example",
            name="example-profile",
            resource_group_name=example.name,
            sku_name="Premium_AzureFrontDoor")
        example_frontdoor_endpoint = azure.cdn.FrontdoorEndpoint("example",
            name="example-endpoint",
            cdn_frontdoor_profile_id=example_frontdoor_profile.id,
            tags={
                "endpoint": "contoso.com",
            })
        example_frontdoor_origin_group = azure.cdn.FrontdoorOriginGroup("example",
            name="example-originGroup",
            cdn_frontdoor_profile_id=example_frontdoor_profile.id,
            session_affinity_enabled=True,
            restore_traffic_time_to_healed_or_new_endpoint_in_minutes=10,
            health_probe={
                "interval_in_seconds": 240,
                "path": "/healthProbe",
                "protocol": "Https",
                "request_type": "GET",
            },
            load_balancing={
                "additional_latency_in_milliseconds": 0,
                "sample_size": 16,
                "successful_samples_required": 3,
            })
        example_frontdoor_origin = azure.cdn.FrontdoorOrigin("example",
            name="example-origin",
            cdn_frontdoor_origin_group_id=example_frontdoor_origin_group.id,
            enabled=True,
            certificate_name_check_enabled=False,
            host_name=example_frontdoor_endpoint.host_name,
            http_port=80,
            https_port=443,
            origin_host_header="contoso.com",
            priority=1,
            weight=500)
        example_frontdoor_rule_set = azure.cdn.FrontdoorRuleSet("example",
            name="exampleruleset",
            cdn_frontdoor_profile_id=example_frontdoor_profile.id)
        example_frontdoor_rule = azure.cdn.FrontdoorRule("example",
            name="examplerule",
            cdn_frontdoor_rule_set_id=example_frontdoor_rule_set.id,
            order=1,
            behavior_on_match="Continue",
            actions={
                "route_configuration_override_action": {
                    "cdn_frontdoor_origin_group_id": example_frontdoor_origin_group.id,
                    "forwarding_protocol": "HttpsOnly",
                    "query_string_caching_behavior": "IncludeSpecifiedQueryStrings",
                    "query_string_parameters": [
                        "foo",
                        "clientIp={client_ip}",
                    ],
                    "compression_enabled": True,
                    "cache_behavior": "OverrideIfOriginMissing",
                    "cache_duration": "365.23:59:59",
                },
                "url_redirect_action": {
                    "redirect_type": "PermanentRedirect",
                    "redirect_protocol": "MatchRequest",
                    "query_string": "clientIp={client_ip}",
                    "destination_path": "/exampleredirection",
                    "destination_hostname": "contoso.com",
                    "destination_fragment": "UrlRedirect",
                },
            },
            conditions={
                "host_name_conditions": [{
                    "operator": "Equal",
                    "negate_condition": False,
                    "match_values": [
                        "www.contoso.com",
                        "images.contoso.com",
                        "video.contoso.com",
                    ],
                    "transforms": [
                        "Lowercase",
                        "Trim",
                    ],
                }],
                "is_device_conditions": [{
                    "operator": "Equal",
                    "negate_condition": False,
                    "match_values": "Mobile",
                }],
                "post_args_conditions": [{
                    "post_args_name": "customerName",
                    "operator": "BeginsWith",
                    "match_values": [
                        "J",
                        "K",
                    ],
                    "transforms": ["Uppercase"],
                }],
                "request_method_conditions": [{
                    "operator": "Equal",
                    "negate_condition": False,
                    "match_values": ["DELETE"],
                }],
                "url_filename_conditions": [{
                    "operator": "Equal",
                    "negate_condition": False,
                    "match_values": ["media.mp4"],
                    "transforms": [
                        "Lowercase",
                        "RemoveNulls",
                        "Trim",
                    ],
                }],
            },
            opts = pulumi.ResourceOptions(depends_on=[
                    example_frontdoor_origin_group,
                    example_frontdoor_origin,
                ]))
        ```

        ## Specifying IP Address Ranges

        When specifying IP address ranges in the `socket_address_condition` and the `remote_address_condition` `match_values` use the following format:

        Use `CIDR` notation when specifying IP address blocks. This means that the syntax for an IP address block is the base IP address followed by a forward slash and the prefix size For example:

        * `IPv4` example: `5.5.5.64/26` matches any requests that arrive from addresses `5.5.5.64` through `5.5.5.127`.
        * `IPv6` example: `1:2:3:/48` matches any requests that arrive from addresses `1:2:3:0:0:0:0:0` through `1:2:3:ffff:ffff:ffff:ffff:ffff`.

        When you specify multiple IP addresses and IP address blocks, `OR` logic is applied.

        * `IPv4` example: if you add two IP addresses `1.2.3.4` and `10.20.30.40`, the condition is matched for any requests that arrive from either address `1.2.3.4` or `10.20.30.40`.
        * `IPv6` example: if you add two IP addresses `1:2:3:4:5:6:7:8` and `10:20:30:40:50:60:70:80`, the condition is matched for any requests that arrive from either address `1:2:3:4:5:6:7:8` or `10:20:30:40:50:60:70:80`.

        ***

        ## Action Server Variables

        Rule Set server variables provide access to structured information about the request. You can use server variables to dynamically change the request/response headers or URL rewrite paths/query strings, for example, when a new page load or when a form is posted.

        ### Supported Action Server Variables

        | Variable name | Description |
        |---------------|-------------|
        | `socket_ip`      | The IP address of the direct connection to Front Door Profiles edge. If the client used an HTTP proxy or a load balancer to send the request, the value of `socket_ip` is the IP address of the proxy or load balancer. |
        | `client_ip`      | The IP address of the client that made the original request. If there was an `X-Forwarded-For` header in the request, then the client IP address is picked from the header. |
        | `client_port`    | The IP port of the client that made the request. |
        | `hostname`       | The host name in the request from the client. |
        | `geo_country`    | Indicates the requester's country/region of origin through its country/region code. |
        | `http_method`    | The method used to make the URL request, such as `GET` or `POST`. |
        | `http_version`   | The request protocol. Usually `HTTP/1.0`, `HTTP/1.1`, or `HTTP/2.0`. |
        | `query_string`   | The list of variable/value pairs that follows the "?" in the requested URL. For example, in the request `http://contoso.com:8080/article.aspx?id=123&title=fabrikam`, the `query_string` value will be `id=123&title=fabrikam`. |
        | `request_scheme` | The request scheme: `http` or `https`. |
        | `request_uri`    | The full original request URI (with arguments). For example, in the request `http://contoso.com:8080/article.aspx?id=123&title=fabrikam`, the `request_uri` value will be `/article.aspx?id=123&title=fabrikam`. |
        | `ssl_protocol`   | The protocol of an established TLS connection. |
        | `server_port`    | The port of the server that accepted a request. |
        | `url_path`       | Identifies the specific resource in the host that the web client wants to access. This is the part of the request URI without the arguments. For example, in the request `http://contoso.com:8080/article.aspx?id=123&title=fabrikam`, the `uri_path` value will be `/article.aspx`. |

        ### Action Server Variable Format

        Server variables can be specified using the following formats:

        * `{variable}` - Include the entire server variable. For example, if the client IP address is `111.222.333.444` then the `{client_ip}` token would evaluate to `111.222.333.444`.

        * `{variable:offset}` - Include the server variable after a specific offset, until the end of the variable. The offset is zero-based. For example, if the client IP address is `111.222.333.444` then the `{client_ip:3}` token would evaluate to `.222.333.444`.

        * `{variable:offset:length}` - Include the server variable after a specific offset, up to the specified length. The offset is zero-based. For example, if the client IP address is `111.222.333.444` then the `{client_ip:4:3}` token would evaluate to `222`.

        ### Action Server Variables Support

        Action Server variables are supported on the following actions:

        * `route_configuration_override_action`
        * `request_header_action`
        * `response_header_action`
        * `url_redirect_action`
        * `url_rewrite_action`

        ***

        ## Condition Operator list

        For rules that accept values from the standard operator list, the following operators are valid:

        | Operator                   | Description | Condition Value |
        |----------------------------|-------------|-----------------|
        | Any                        |Matches when there is any value, regardless of what it is. | Any |
        | Equal                      | Matches when the value exactly matches the specified string. | Equal |
        | Contains                   | Matches when the value contains the specified string. | Contains |
        | Less Than                  | Matches when the length of the value is less than the specified integer. | LessThan |
        | Greater Than               | Matches when the length of the value is greater than the specified integer. | GreaterThan |
        | Less Than or Equal         | Matches when the length of the value is less than or equal to the specified integer. | LessThanOrEqual |
        | Greater Than or Equal      | Matches when the length of the value is greater than or equal to the specified integer. | GreaterThanOrEqual |
        | Begins With                | Matches when the value begins with the specified string. | BeginsWith |
        | Ends With                  | Matches when the value ends with the specified string. | EndsWith |
        | RegEx                      | Matches when the value matches the specified regular expression. See below for further details. | RegEx |
        | Not Any                    | Matches when there is no value. | Any and negateCondition = true |
        | Not Equal                  | Matches when the value does not match the specified string. | Equal and negateCondition : true |
        | Not Contains               | Matches when the value does not contain the specified string. | Contains and negateCondition = true |
        | Not Less Than              | Matches when the length of the value is not less than the specified integer. | LessThan and negateCondition = true |
        | Not Greater Than           | Matches when the length of the value is not greater than the specified integer. | GreaterThan and negateCondition = true |
        | Not Less Than or Equal     | Matches when the length of the value is not less than or equal to the specified integer. | LessThanOrEqual and negateCondition = true |
        | Not Greater Than or Equals | Matches when the length of the value is not greater than or equal to the specified integer. | GreaterThanOrEqual and negateCondition = true |
        | Not Begins With            | Matches when the value does not begin with the specified string. | BeginsWith and negateCondition = true |
        | Not Ends With              | Matches when the value does not end with the specified string. | EndsWith and negateCondition = true |
        | Not RegEx                  | Matches when the value does not match the specified regular expression. See `Condition Regular Expressions` for further details. | RegEx and negateCondition = true |

        ***

        ## Condition Regular Expressions

        Regular expressions **don't** support the following operations:

        * Backreferences and capturing subexpressions.
        * Arbitrary zero-width assertions.
        * Subroutine references and recursive patterns.
        * Conditional patterns.
        * Backtracking control verbs.
        * The `\\C` single-byte directive.
        * The `\\R` newline match directive.
        * The `\\K` start of match reset directive.
        * Callouts and embedded code.
        * Atomic grouping and possessive quantifiers.

        ***

        ## Condition Transform List

        For rules that can transform strings, the following transforms are valid:

        | Transform   | Description |
        |-------------|-------------|
        | Lowercase   | Converts the string to the lowercase representation. |
        | Uppercase   | Converts the string to the uppercase representation. |
        | Trim        | Trims leading and trailing whitespace from the string. |
        | RemoveNulls | Removes null values from the string. |
        | URLEncode   | URL-encodes the string. |
        | URLDecode   | URL-decodes the string. |

        ***

        ## Import

        Front Door Rules can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:cdn/frontdoorRule:FrontdoorRule example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup1/providers/Microsoft.Cdn/profiles/profile1/ruleSets/ruleSet1/rules/rule1
        ```

        :param str resource_name: The name of the resource.
        :param FrontdoorRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FrontdoorRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 actions: Optional[pulumi.Input[Union['FrontdoorRuleActionsArgs', 'FrontdoorRuleActionsArgsDict']]] = None,
                 behavior_on_match: Optional[pulumi.Input[str]] = None,
                 cdn_frontdoor_rule_set_id: Optional[pulumi.Input[str]] = None,
                 conditions: Optional[pulumi.Input[Union['FrontdoorRuleConditionsArgs', 'FrontdoorRuleConditionsArgsDict']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 order: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FrontdoorRuleArgs.__new__(FrontdoorRuleArgs)

            if actions is None and not opts.urn:
                raise TypeError("Missing required property 'actions'")
            __props__.__dict__["actions"] = actions
            __props__.__dict__["behavior_on_match"] = behavior_on_match
            if cdn_frontdoor_rule_set_id is None and not opts.urn:
                raise TypeError("Missing required property 'cdn_frontdoor_rule_set_id'")
            __props__.__dict__["cdn_frontdoor_rule_set_id"] = cdn_frontdoor_rule_set_id
            __props__.__dict__["conditions"] = conditions
            __props__.__dict__["name"] = name
            if order is None and not opts.urn:
                raise TypeError("Missing required property 'order'")
            __props__.__dict__["order"] = order
            __props__.__dict__["cdn_frontdoor_rule_set_name"] = None
        super(FrontdoorRule, __self__).__init__(
            'azure:cdn/frontdoorRule:FrontdoorRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            actions: Optional[pulumi.Input[Union['FrontdoorRuleActionsArgs', 'FrontdoorRuleActionsArgsDict']]] = None,
            behavior_on_match: Optional[pulumi.Input[str]] = None,
            cdn_frontdoor_rule_set_id: Optional[pulumi.Input[str]] = None,
            cdn_frontdoor_rule_set_name: Optional[pulumi.Input[str]] = None,
            conditions: Optional[pulumi.Input[Union['FrontdoorRuleConditionsArgs', 'FrontdoorRuleConditionsArgsDict']]] = None,
            name: Optional[pulumi.Input[str]] = None,
            order: Optional[pulumi.Input[int]] = None) -> 'FrontdoorRule':
        """
        Get an existing FrontdoorRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['FrontdoorRuleActionsArgs', 'FrontdoorRuleActionsArgsDict']] actions: An `actions` block as defined below.
        :param pulumi.Input[str] behavior_on_match: If this rule is a match should the rules engine continue processing the remaining rules or stop? Possible values are `Continue` and `Stop`. Defaults to `Continue`.
        :param pulumi.Input[str] cdn_frontdoor_rule_set_id: The resource ID of the Front Door Rule Set for this Front Door Rule. Changing this forces a new Front Door Rule to be created.
        :param pulumi.Input[str] cdn_frontdoor_rule_set_name: The name of the Front Door Rule Set containing this Front Door Rule.
        :param pulumi.Input[Union['FrontdoorRuleConditionsArgs', 'FrontdoorRuleConditionsArgsDict']] conditions: A `conditions` block as defined below.
        :param pulumi.Input[str] name: The name which should be used for this Front Door Rule. Possible values must be between 1 and 260 characters in length, begin with a letter and may contain only letters and numbers. Changing this forces a new Front Door Rule to be created.
        :param pulumi.Input[int] order: The order in which the rules will be applied for the Front Door Endpoint. The order value should be sequential and begin at `1`(e.g. `1`, `2`, `3`...). A Front Door Rule with a lesser order value will be applied before a rule with a greater order value.
               
               ->**NOTE:** If the Front Door Rule has an order value of `0` they do not require any conditions and the actions will always be applied.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FrontdoorRuleState.__new__(_FrontdoorRuleState)

        __props__.__dict__["actions"] = actions
        __props__.__dict__["behavior_on_match"] = behavior_on_match
        __props__.__dict__["cdn_frontdoor_rule_set_id"] = cdn_frontdoor_rule_set_id
        __props__.__dict__["cdn_frontdoor_rule_set_name"] = cdn_frontdoor_rule_set_name
        __props__.__dict__["conditions"] = conditions
        __props__.__dict__["name"] = name
        __props__.__dict__["order"] = order
        return FrontdoorRule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def actions(self) -> pulumi.Output['outputs.FrontdoorRuleActions']:
        """
        An `actions` block as defined below.
        """
        return pulumi.get(self, "actions")

    @property
    @pulumi.getter(name="behaviorOnMatch")
    def behavior_on_match(self) -> pulumi.Output[Optional[str]]:
        """
        If this rule is a match should the rules engine continue processing the remaining rules or stop? Possible values are `Continue` and `Stop`. Defaults to `Continue`.
        """
        return pulumi.get(self, "behavior_on_match")

    @property
    @pulumi.getter(name="cdnFrontdoorRuleSetId")
    def cdn_frontdoor_rule_set_id(self) -> pulumi.Output[str]:
        """
        The resource ID of the Front Door Rule Set for this Front Door Rule. Changing this forces a new Front Door Rule to be created.
        """
        return pulumi.get(self, "cdn_frontdoor_rule_set_id")

    @property
    @pulumi.getter(name="cdnFrontdoorRuleSetName")
    def cdn_frontdoor_rule_set_name(self) -> pulumi.Output[str]:
        """
        The name of the Front Door Rule Set containing this Front Door Rule.
        """
        return pulumi.get(self, "cdn_frontdoor_rule_set_name")

    @property
    @pulumi.getter
    def conditions(self) -> pulumi.Output[Optional['outputs.FrontdoorRuleConditions']]:
        """
        A `conditions` block as defined below.
        """
        return pulumi.get(self, "conditions")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name which should be used for this Front Door Rule. Possible values must be between 1 and 260 characters in length, begin with a letter and may contain only letters and numbers. Changing this forces a new Front Door Rule to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def order(self) -> pulumi.Output[int]:
        """
        The order in which the rules will be applied for the Front Door Endpoint. The order value should be sequential and begin at `1`(e.g. `1`, `2`, `3`...). A Front Door Rule with a lesser order value will be applied before a rule with a greater order value.

        ->**NOTE:** If the Front Door Rule has an order value of `0` they do not require any conditions and the actions will always be applied.
        """
        return pulumi.get(self, "order")

